-- MySQL dump 9.10
--
-- Host: localhost    Database: porta-billing
-- ------------------------------------------------------
-- Server version	4.0.18-log

--
-- Databases
--
DROP DATABASE IF EXISTS `porta-billing`;
CREATE DATABASE `porta-billing`;
USE `porta-billing`;

--
-- Table structure for table `ASR_Vendors`
--

CREATE TABLE ASR_Vendors (
  id int(10) unsigned NOT NULL auto_increment,
  i_dest int(10) unsigned NOT NULL default '0',
  i_vendor int(10) unsigned NOT NULL default '0',
  attempts int(10) unsigned NOT NULL default '0',
  calls int(10) unsigned NOT NULL default '0',
  duration int(10) unsigned NOT NULL default '0',
  day date NOT NULL default '0000-00-00',
  PRIMARY KEY  (id),
  KEY i_dest_index (i_dest)
) TYPE=InnoDB;

--
-- Table structure for table `Abbreviated_Dialing`
--

CREATE TABLE Abbreviated_Dialing (
  i_ab_dialing int(10) unsigned NOT NULL auto_increment,
  i_customer int(10) unsigned NOT NULL default '0',
  abbreviated_number char(15) NOT NULL default '',
  number_to_dial char(32) default NULL,
  description char(64) default '',
  PRIMARY KEY  (i_ab_dialing),
  UNIQUE KEY customer_number (i_customer,abbreviated_number)
) TYPE=InnoDB;

--
-- Table structure for table `Access_Level_Notepad`
--

CREATE TABLE Access_Level_Notepad (
  i_acl int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_acl)
) TYPE=InnoDB;

--
-- Table structure for table `Access_Level_Types`
--

CREATE TABLE Access_Level_Types (
  i_acl_type int(10) unsigned NOT NULL auto_increment,
  name char(64) default NULL,
  PRIMARY KEY  (i_acl_type)
) TYPE=InnoDB;

--
-- Table structure for table `Access_Levels`
--

CREATE TABLE Access_Levels (
  i_acl int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned default NULL,
  name char(64) default NULL,
  subsystem char(32) default NULL,
  acl_group char(32) default NULL,
  hidden char(1) NOT NULL default 'N',
  i_acl_type int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_acl),
  UNIQUE KEY Acl (i_env,name)
) TYPE=InnoDB;

--
-- Table structure for table `Access_Levels_Inheritance`
--

CREATE TABLE Access_Levels_Inheritance (
  i_acl_inheritance int(10) NOT NULL auto_increment,
  i_acl int(10) unsigned NOT NULL default '0',
  acl_order int(3) unsigned NOT NULL default '0',
  i_acl_parent int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_acl_inheritance),
  UNIQUE KEY Parent (i_acl,i_acl_parent)
) TYPE=InnoDB;

--
-- Table structure for table `Access_Levels_Permissions`
--

CREATE TABLE Access_Levels_Permissions (
  i_acl_perm int(10) unsigned NOT NULL auto_increment,
  i_acl int(10) unsigned NOT NULL default '0',
  access_type char(10) NOT NULL default 'READ',
  mode enum('allow','deny') NOT NULL default 'allow',
  object char(48) NOT NULL default '',
  attribute char(32) NOT NULL default '',
  PRIMARY KEY  (i_acl_perm),
  UNIQUE KEY Perm (i_acl,access_type,object,attribute)
) TYPE=InnoDB;

--
-- Table structure for table `Accessibility`
--

CREATE TABLE Accessibility (
  i_accessibility int(10) unsigned NOT NULL auto_increment,
  i_product int(10) unsigned NOT NULL default '0',
  i_tariff int(10) unsigned NOT NULL default '0',
  i_node int(10) unsigned default NULL,
  CLD char(15) default NULL,
  i_oli int(10) unsigned default NULL,
  PRIMARY KEY  (i_accessibility),
  KEY Accessibility_CLD (CLD),
  KEY i_tariff (i_tariff)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `Account_Notepad`
--

CREATE TABLE Account_Notepad (
  i_account int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `Account_Subscriptions`
--

CREATE TABLE Account_Subscriptions (
  i_account_subscription int(10) unsigned NOT NULL auto_increment,
  i_account int(10) unsigned NOT NULL default '0',
  i_subscription int(10) unsigned NOT NULL default '0',
  start_date date NOT NULL default '0000-00-00',
  activation_date date default NULL,
  finish_date date default NULL,
  billed_to date default NULL,
  obligatory enum('N','Y') NOT NULL default 'N',
  last_cdr_id int(10) unsigned default NULL,
  last_closed_period date default NULL,
  is_finished enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (i_account_subscription),
  KEY account_subscription (i_account,i_subscription),
  KEY comp_start_date (i_account,start_date),
  KEY comp_finish_date (i_account,finish_date),
  KEY comp_billed_to (i_account,billed_to)
) TYPE=MyISAM;

--
-- Table structure for table `Account_Volume_Discount_Counters`
--

CREATE TABLE Account_Volume_Discount_Counters (
  i_avd_counter int(10) unsigned NOT NULL auto_increment,
  i_account int(10) unsigned NOT NULL default '0',
  i_dest_group int(10) unsigned NOT NULL default '0',
  period_from datetime NOT NULL default '0000-00-00 00:00:00',
  period_to datetime default NULL,
  counter decimal(15,5) NOT NULL default '0.00000',
  PRIMARY KEY  (i_avd_counter)
) TYPE=InnoDB;

--
-- Table structure for table `Accounts`
--

CREATE TABLE Accounts (
  i_account int(10) unsigned NOT NULL auto_increment,
  id char(32) NOT NULL default '',
  password char(16) default NULL,
  h323_password char(255) default NULL,
  balance decimal(15,5) NOT NULL default '0.00000',
  opening_balance decimal(15,5) NOT NULL default '0.00000',
  issue_date date NOT NULL default '0000-00-00',
  zero_balance_date date default NULL,
  i_customer int(10) unsigned NOT NULL default '0',
  billing_model tinyint(2) NOT NULL default '0',
  activation_date date NOT NULL default '0000-00-00',
  expiration_date date default NULL,
  i_product int(10) unsigned NOT NULL default '0',
  blocked char(1) NOT NULL default 'N',
  last_usage datetime default NULL,
  i_batch int(10) unsigned NOT NULL default '0',
  i_env tinyint(1) unsigned NOT NULL default '1',
  first_usage date default NULL,
  life_time smallint(4) unsigned default NULL,
  redirect_number char(15) default NULL,
  control_number int(10) unsigned NOT NULL default '0',
  iso_639_1 char(2) default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  credit_limit decimal(15,5) default NULL,
  iso_4217 char(3) NOT NULL default '',
  non_call_related_charges decimal(15,5) default NULL,
  refunds decimal(15,5) default NULL,
  login char(32) default NULL,
  email char(128) default NULL,
  password_timestamp datetime default NULL,
  um_enabled char(1) NOT NULL default 'N',
  i_acl int(10) unsigned NOT NULL default '155',
  i_subscriber int(10) unsigned default NULL,
  i_lang char(5) default NULL,
  ua_profile_id int(10) unsigned default NULL,
  mac char(23) default NULL,
  i_ua_profile int(10) unsigned default NULL,
  follow_me_enabled char(1) NOT NULL default 'N',
  timer datetime default NULL,
  ecommerce_enabled char(1) default 'N',
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  i_vd_plan int(10) unsigned default NULL,
  last_recharge datetime default NULL,
  i_moh int(10) unsigned default NULL,
  service_flags char(32) NOT NULL default '',
  PRIMARY KEY  (i_account),
  UNIQUE KEY Accounts_id (id,i_env),
  UNIQUE KEY Accounts_cn_batch (i_batch,control_number),
  UNIQUE KEY Accounts_login (login),
  KEY Account_customer (i_customer),
  KEY Accounts_acl (i_acl),
  KEY Accounts_i_product (i_product),
  KEY Accounts_product (i_product),
  KEY AccountsProfileId (ua_profile_id),
  KEY Accounts_mac (mac,i_env),
  KEY Accounts_um_enabled (um_enabled),
  KEY Accounts_iso_4217 (iso_4217),
  KEY AccountFirstUsage (first_usage),
  KEY i_vd_plan (i_vd_plan),
  KEY accounts_maintenance (i_product,blocked,expiration_date)
) TYPE=InnoDB;

--
-- Table structure for table `Active_Calls`
--

CREATE TABLE Active_Calls (
  i_active_callleg int(10) unsigned NOT NULL auto_increment,
  h323_conf_id char(36) default NULL,
  call_id char(64) default NULL,
  i_env int(10) unsigned NOT NULL default '0',
  i_node int(10) unsigned NOT NULL default '0',
  call_type enum('VoIP','Telephony') NOT NULL default 'VoIP',
  call_origin enum('answer','originate') NOT NULL default 'answer',
  port char(32) NOT NULL default '',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  update_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime default NULL,
  CLI char(32) default NULL,
  CLD char(32) default NULL,
  i_account int(10) unsigned default NULL,
  i_customer int(10) unsigned default NULL,
  i_connection int(10) unsigned default NULL,
  PRIMARY KEY  (i_active_callleg)
) TYPE=InnoDB;

--
-- Table structure for table `Active_Sessions`
--

CREATE TABLE Active_Sessions (
  i_session int(10) NOT NULL auto_increment,
  i_account int(10) default NULL,
  call_id varchar(36) default NULL,
  sessiontime timestamp(14) NOT NULL,
  PRIMARY KEY  (i_session),
  KEY i_account (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `Active_rates`
--

CREATE TABLE Active_rates (
  iso_4217 char(3) NOT NULL default '',
  base_units decimal(15,5) unsigned default NULL,
  i_env tinyint(4) default NULL,
  KEY iso_env (i_env,iso_4217)
) TYPE=InnoDB;

--
-- Table structure for table `BE_Version`
--

CREATE TABLE BE_Version (
  version char(32) default NULL,
  comment char(100) default NULL
) TYPE=InnoDB;

--
-- Table structure for table `Batch`
--

CREATE TABLE Batch (
  i_batch int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  iso_4217 char(3) NOT NULL default '',
  description char(255) default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_customer int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_batch),
  UNIQUE KEY batch (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Billing_Models`
--

CREATE TABLE Billing_Models (
  billing_model tinyint(1) NOT NULL default '0',
  name char(32) NOT NULL default '',
  PRIMARY KEY  (billing_model)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `Billing_Period`
--

CREATE TABLE Billing_Period (
  i_billing_period tinyint(2) unsigned NOT NULL auto_increment,
  description char(32) NOT NULL default '',
  PRIMARY KEY  (i_billing_period)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `CC_Staff`
--

CREATE TABLE CC_Staff (
  i_cc_staff int(10) unsigned NOT NULL auto_increment,
  login char(32) NOT NULL default '',
  password char(32) NOT NULL default '',
  i_customer int(10) unsigned NOT NULL default '0',
  description char(128) NOT NULL default '',
  email char(128) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  activation_date date NOT NULL default '0000-00-00',
  expiration_date date default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  daily_allovance decimal(15,5) NOT NULL default '0.00000',
  transaction_allovance decimal(15,5) NOT NULL default '0.00000',
  refunded_today decimal(15,5) NOT NULL default '0.00000',
  refunds_counter smallint(5) unsigned NOT NULL default '0',
  senior char(1) NOT NULL default 'N',
  rst datetime default NULL,
  search_counter smallint(5) unsigned NOT NULL default '0',
  password_timestamp datetime default NULL,
  i_acl int(10) unsigned NOT NULL default '0',
  i_lang char(5) default NULL,
  companyname char(41) NOT NULL default '',
  salutation char(15) NOT NULL default '',
  firstname char(25) NOT NULL default '',
  midinit char(5) NOT NULL default '',
  lastname char(25) NOT NULL default '',
  baddr1 char(41) NOT NULL default '',
  baddr2 char(41) NOT NULL default '',
  baddr3 char(41) NOT NULL default '',
  baddr4 char(41) NOT NULL default '',
  baddr5 char(41) NOT NULL default '',
  city char(31) NOT NULL default '',
  state char(21) NOT NULL default '',
  zip char(13) NOT NULL default '',
  country char(31) NOT NULL default '',
  cont1 char(41) NOT NULL default '',
  phone1 char(21) NOT NULL default '',
  faxnum char(21) NOT NULL default '',
  phone2 char(21) NOT NULL default '',
  cont2 char(41) NOT NULL default '',
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  PRIMARY KEY  (i_cc_staff),
  UNIQUE KEY login_index (login),
  KEY CC_Staff_env (i_env),
  KEY CC_Staff_acl (i_acl)
) TYPE=InnoDB;

--
-- Table structure for table `CC_Staff_Notepad`
--

CREATE TABLE CC_Staff_Notepad (
  i_cc_staff int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_cc_staff)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_Accounts`
--

CREATE TABLE CDR_Accounts (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  voice_quality tinyint(2) unsigned default NULL,
  duration mediumint(8) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  acc_flag char(1) NOT NULL default 'V',
  account_id char(32) default NULL,
  i_dest int(10) unsigned NOT NULL default '0',
  charged_time mediumint(8) unsigned NOT NULL default '0',
  charged_amount decimal(15,5) default NULL,
  history char(32) default NULL,
  i_vendor int(10) unsigned default NULL,
  cost decimal(15,5) default NULL,
  i_customer int(10) unsigned NOT NULL default '0',
  call_id char(1) default NULL,
  i_account int(10) unsigned default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_disconnect_time (disconnect_time),
  KEY CDR_i_dest (i_dest),
  KEY i_account (i_account),
  KEY account_id (i_env,account_id),
  KEY conf_id (h323_conf_id),
  KEY comp_customer_connect_time (i_customer,connect_time),
  KEY comp_account_connect_time (i_account,connect_time)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_Accounts_Failed`
--

CREATE TABLE CDR_Accounts_Failed (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  account_id char(32) default NULL,
  i_dest int(10) unsigned NOT NULL default '0',
  i_customer int(10) unsigned NOT NULL default '0',
  call_id char(1) default NULL,
  i_account int(10) unsigned default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_i_dest (i_dest),
  KEY i_account (i_account),
  KEY account_id (i_env,account_id),
  KEY conf_id (h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_Customers`
--

CREATE TABLE CDR_Customers (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  voice_quality tinyint(2) unsigned default NULL,
  duration mediumint(8) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  acc_flag char(1) NOT NULL default 'V',
  i_customer int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  charged_time mediumint(8) unsigned NOT NULL default '0',
  charged_amount decimal(15,5) default NULL,
  history char(32) default NULL,
  i_vendor int(10) unsigned default NULL,
  cost decimal(15,5) default NULL,
  call_id char(1) default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY i_customer (i_customer),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_disconnect_time (disconnect_time),
  KEY CDR_i_dest (i_dest),
  KEY conf_id (i_env,h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_Customers_Failed`
--

CREATE TABLE CDR_Customers_Failed (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  i_customer int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  call_id char(1) default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY i_customer (i_customer),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_i_dest (i_dest),
  KEY conf_id (i_env,h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_OnNet`
--

CREATE TABLE CDR_OnNet (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned default NULL,
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  voice_quality tinyint(2) unsigned default NULL,
  duration mediumint(8) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  acc_flag char(1) NOT NULL default 'V',
  account_id char(32) default NULL,
  history char(32) default NULL,
  i_customer int(10) unsigned default NULL,
  call_id char(1) default NULL,
  i_account int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY account_id (account_id),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_disconnect_time (disconnect_time),
  KEY cdr_a_conf_id (h323_conf_id),
  KEY call_id (call_id),
  KEY conf_id (i_env,h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_Vendors`
--

CREATE TABLE CDR_Vendors (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  voice_quality tinyint(2) unsigned default NULL,
  duration mediumint(8) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  acc_flag char(1) NOT NULL default 'V',
  i_vendor int(10) unsigned NOT NULL default '0',
  i_connection int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  i_customer int(10) unsigned default NULL,
  revenue decimal(15,5) default NULL,
  charged_time mediumint(8) unsigned NOT NULL default '0',
  charged_amount decimal(15,5) default NULL,
  history char(32) default NULL,
  account_id char(32) default NULL,
  call_id char(1) default NULL,
  i_account int(10) unsigned default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY i_vendor (i_vendor),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_disconnect_time (disconnect_time),
  KEY CDR_i_dest (i_dest),
  KEY i_account (i_account),
  KEY conf_id (i_env,h323_conf_id),
  KEY comp_disc_conn_time_env (disconnect_time,connect_time,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `CDR_Vendors_Failed`
--

CREATE TABLE CDR_Vendors_Failed (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  i_vendor int(10) unsigned NOT NULL default '0',
  i_connection bigint(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  account_id char(32) default NULL,
  i_customer int(10) unsigned default NULL,
  call_id char(1) default NULL,
  i_account int(10) unsigned default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY i_vendor (i_vendor),
  KEY CLD_index (CLD),
  KEY CDR_connect_time (connect_time),
  KEY CDR_i_dest (i_dest),
  KEY i_account (i_account),
  KEY conf_id (i_env,h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `Component_Types`
--

CREATE TABLE Component_Types (
  i_component_type smallint(5) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  editor_order smallint(5) unsigned NOT NULL default '0',
  handler char(255) default NULL,
  PRIMARY KEY  (i_component_type),
  UNIQUE KEY component_type (name)
) TYPE=InnoDB;

--
-- Table structure for table `Connections`
--

CREATE TABLE Connections (
  i_connection int(10) unsigned NOT NULL auto_increment,
  i_vendor int(10) unsigned NOT NULL default '0',
  description char(255) NOT NULL default '',
  i_node int(10) unsigned default NULL,
  i_tariff int(10) unsigned default NULL,
  call_origin enum('answer','originate','callback','proxy','unknown') NOT NULL default 'unknown',
  call_type enum('Telephony','VoIP','unknown') NOT NULL default 'unknown',
  port char(64) default NULL,
  CLD char(32) default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  cld_translation_rule char(255) default NULL,
  remote_ip char(64) default NULL,
  capacity smallint(5) unsigned NOT NULL default '0',
  asr float(7,4) default NULL,
  i_vendor_acc int(10) unsigned default NULL,
  outgoing_cld_translation_rule char(255) default NULL,
  i_oli int(10) unsigned default NULL,
  sip enum('Y','N') NOT NULL default 'Y',
  h323 enum('Y','N') NOT NULL default 'N',
  cli_translation_rule char(255) default NULL,
  rtpp_level tinyint(1) unsigned default NULL,
  PRIMARY KEY  (i_connection),
  KEY Connection_i_vendor (i_vendor),
  KEY Connections_port (port),
  KEY i_tariff (i_tariff)
) TYPE=InnoDB;

--
-- Table structure for table `Countries`
--

CREATE TABLE Countries (
  name char(64) NOT NULL default '',
  iso_3166_1_a2 char(2) NOT NULL default '',
  iso_3166_1_a3 char(3) NOT NULL default '',
  iso_3166_1_num smallint(3) unsigned NOT NULL default '0',
  PRIMARY KEY  (iso_3166_1_num),
  UNIQUE KEY iso_3166_1_a2 (iso_3166_1_a2),
  UNIQUE KEY iso_3166_1_a3 (iso_3166_1_a3),
  KEY iso_a2_name (iso_3166_1_a2,name)
) TYPE=InnoDB;

--
-- Table structure for table `Country_Currency`
--

CREATE TABLE Country_Currency (
  iso_3166_1_a2 char(2) NOT NULL default '',
  iso_4217 char(3) NOT NULL default '',
  PRIMARY KEY  (iso_3166_1_a2,iso_4217)
) TYPE=InnoDB;

--
-- Table structure for table `Country_Subdivision`
--

CREATE TABLE Country_Subdivision (
  i_country_subdivision smallint(5) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  iso_3166_1_a2 char(2) NOT NULL default '',
  iso_3166_2 char(16) NOT NULL default '',
  PRIMARY KEY  (i_country_subdivision),
  UNIQUE KEY iso_3166_1_a2 (iso_3166_1_a2,iso_3166_2)
) TYPE=InnoDB;

--
-- Table structure for table `Credit_Cards`
--

CREATE TABLE Credit_Cards (
  i_credit_card int(10) unsigned NOT NULL auto_increment,
  refnum varchar(32) default NULL,
  i_payment_method tinyint(2) unsigned default NULL,
  number blob,
  exp_date date default NULL,
  name varchar(41) default NULL,
  address varchar(41) default NULL,
  zip varchar(41) default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  cvv varchar(16) default NULL,
  i_country_subdivision smallint(5) unsigned default NULL,
  iso_3166_1_a2 char(2) default NULL,
  city varchar(50) default NULL,
  issue_no varchar(4) default NULL,
  start_date date default NULL,
  PRIMARY KEY  (i_credit_card)
) TYPE=InnoDB;

--
-- Table structure for table `Credit_Limit_Warnings`
--

CREATE TABLE Credit_Limit_Warnings (
  i_customer int(10) unsigned NOT NULL auto_increment,
  last_send_date datetime NOT NULL default '0000-00-00 00:00:00',
  last_send_status char(25) NOT NULL default '',
  PRIMARY KEY  (i_customer)
) TYPE=InnoDB;

--
-- Table structure for table `Currencies`
--

CREATE TABLE Currencies (
  name char(64) NOT NULL default '',
  iso_4217 char(3) NOT NULL default '',
  iso_4217_num smallint(3) unsigned default '0',
  decimal_digits tinyint(1) unsigned default NULL,
  name_major char(32) default NULL,
  name_minor char(32) default NULL,
  PRIMARY KEY  (iso_4217)
) TYPE=InnoDB;

--
-- Table structure for table `Custom_Report_Queries`
--

CREATE TABLE Custom_Report_Queries (
  i_cr_query int(10) unsigned NOT NULL auto_increment,
  i_custom_report int(10) unsigned NOT NULL default '0',
  i_env int(10) unsigned NOT NULL default '0',
  i_time_zone int(10) unsigned default NULL,
  name varchar(32) NOT NULL default '',
  description varchar(128) default NULL,
  i_owner int(10) unsigned NOT NULL default '0',
  owner enum('admin','representative') NOT NULL default 'admin',
  input_values blob,
  output_formats blob,
  send_to_owner enum('Y','N') default 'Y',
  send_copy varchar(32) default NULL,
  include_parameters enum('Y','N') default 'Y',
  PRIMARY KEY  (i_cr_query),
  UNIQUE KEY i_cr_query (i_cr_query),
  UNIQUE KEY env_name (i_env,name),
  KEY AI_i_cr_query (i_cr_query),
  KEY owner_report (owner,i_owner,i_custom_report)
) TYPE=InnoDB;

--
-- Table structure for table `Custom_Report_Query_Notepad`
--

CREATE TABLE Custom_Report_Query_Notepad (
  i_cr_query int(10) unsigned NOT NULL default '0',
  notepad text,
  PRIMARY KEY  (i_cr_query)
) TYPE=InnoDB;

--
-- Table structure for table `Custom_Report_Queue`
--

CREATE TABLE Custom_Report_Queue (
  i_cr_queue int(10) unsigned NOT NULL auto_increment,
  i_cr_query int(10) unsigned NOT NULL default '0',
  i_env int(10) unsigned NOT NULL default '0',
  start_time datetime default NULL,
  last_run datetime default NULL,
  suspended enum('Y','N') NOT NULL default 'N',
  execution_status enum('Running','Completed','Waiting') default 'Waiting',
  periodical enum('Daily','Weekly','Monthly') default NULL,
  PRIMARY KEY  (i_cr_queue),
  KEY AI_i_cr_queue (i_cr_queue),
  KEY i_cr_query (i_cr_query),
  KEY i_env (i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Custom_Report_Results`
--

CREATE TABLE Custom_Report_Results (
  i_cr_result int(10) unsigned NOT NULL auto_increment,
  i_cr_query int(10) unsigned NOT NULL default '0',
  start_time datetime NOT NULL default '0000-00-00 00:00:00',
  completion_time datetime NOT NULL default '0000-00-00 00:00:00',
  file varchar(255) NOT NULL default '',
  PRIMARY KEY  (i_cr_result),
  KEY AI_i_cr_result (i_cr_result),
  KEY i_cr_query (i_cr_query)
) TYPE=InnoDB;

--
-- Table structure for table `Custom_Reports`
--

CREATE TABLE Custom_Reports (
  i_custom_report int(10) unsigned NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  object varchar(255) default NULL,
  PRIMARY KEY  (i_custom_report),
  UNIQUE KEY i_custom_report (i_custom_report),
  UNIQUE KEY name (name),
  KEY AI_i_custom_report (i_custom_report)
) TYPE=InnoDB;

--
-- Table structure for table `Customer_Classes`
--

CREATE TABLE Customer_Classes (
  i_customer_class int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_customer int(10) unsigned default NULL,
  description char(255) default NULL,
  i_template int(10) unsigned default NULL,
  i_payment_term int(10) unsigned default NULL,
  grace_period smallint(4) unsigned default NULL,
  notific_days char(255) default NULL,
  resend_days char(255) default NULL,
  recollect_days char(255) default NULL,
  warning_days smallint(4) unsigned default NULL,
  suspension_days smallint(4) unsigned default NULL,
  closing_days smallint(4) unsigned default NULL,
  bp_charge_cc enum('N','Y') NOT NULL default 'N',
  PRIMARY KEY  (i_customer_class),
  UNIQUE KEY env_name (i_env,name)
) TYPE=MyISAM;

--
-- Table structure for table `Customer_Notepad`
--

CREATE TABLE Customer_Notepad (
  i_customer int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_customer)
) TYPE=InnoDB;

--
-- Table structure for table `Customer_Subscriptions`
--

CREATE TABLE Customer_Subscriptions (
  i_customer_subscription int(10) unsigned NOT NULL auto_increment,
  i_customer int(10) unsigned NOT NULL default '0',
  i_subscription int(10) unsigned NOT NULL default '0',
  start_date date NOT NULL default '0000-00-00',
  activation_date date default NULL,
  finish_date date default NULL,
  billed_to date default NULL,
  last_cdr_id int(10) unsigned default NULL,
  last_closed_period date default NULL,
  is_finished enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (i_customer_subscription),
  KEY customer_subscription (i_customer,i_subscription),
  KEY comp_start_date (i_customer,start_date),
  KEY comp_finish_date (i_customer,finish_date),
  KEY comp_billed_to (i_customer,billed_to)
) TYPE=MyISAM;

--
-- Table structure for table `Customer_Types`
--

CREATE TABLE Customer_Types (
  i_customer_type int(10) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  ctype char(31) NOT NULL default '',
  default_i_acl int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_customer_type),
  UNIQUE KEY ct_ctype (ctype)
) TYPE=InnoDB;

--
-- Table structure for table `Customer_Volume_Discount_Counters`
--

CREATE TABLE Customer_Volume_Discount_Counters (
  i_cvd_counter int(10) unsigned NOT NULL auto_increment,
  i_customer int(10) unsigned NOT NULL default '0',
  i_dest_group int(10) unsigned NOT NULL default '0',
  period_from datetime NOT NULL default '0000-00-00 00:00:00',
  period_to datetime default NULL,
  counter decimal(15,5) NOT NULL default '0.00000',
  PRIMARY KEY  (i_cvd_counter)
) TYPE=InnoDB;

--
-- Table structure for table `Customers`
--

CREATE TABLE Customers (
  i_customer int(10) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  name char(41) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  balance decimal(15,5) NOT NULL default '0.00000',
  iso_4217 char(3) NOT NULL default '',
  companyname char(41) NOT NULL default '',
  salutation char(15) NOT NULL default '',
  firstname char(25) NOT NULL default '',
  midinit char(5) NOT NULL default '',
  lastname char(25) NOT NULL default '',
  baddr1 char(41) NOT NULL default '',
  baddr2 char(41) NOT NULL default '',
  baddr3 char(41) NOT NULL default '',
  baddr4 char(41) NOT NULL default '',
  baddr5 char(41) NOT NULL default '',
  city char(31) NOT NULL default '',
  state char(21) NOT NULL default '',
  zip char(13) NOT NULL default '',
  country char(31) NOT NULL default '',
  note char(41) NOT NULL default '',
  cont1 char(41) NOT NULL default '',
  phone1 char(21) NOT NULL default '',
  faxnum char(21) NOT NULL default '',
  phone2 char(21) NOT NULL default '',
  cont2 char(41) NOT NULL default '',
  email char(99) default NULL,
  bcc char(99) default NULL,
  send_statistics char(1) NOT NULL default 'N',
  login char(16) default NULL,
  password char(16) default NULL,
  i_customer_type int(10) unsigned NOT NULL default '1',
  i_billing_period tinyint(2) unsigned NOT NULL default '4',
  i_tariff int(10) unsigned default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  credit_limit decimal(15,5) default NULL,
  i_credit_card int(10) unsigned default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_template int(10) unsigned default NULL,
  tax_id char(16) default NULL,
  i_payment_term int(10) unsigned NOT NULL default '0',
  blocked enum('Y','N') NOT NULL default 'N',
  ppm_enabled char(1) NOT NULL default 'N',
  i_rep int(10) unsigned NOT NULL default '0',
  drm_enabled char(1) NOT NULL default 'N',
  max_abbreviated_length tinyint(1) unsigned default NULL,
  password_timestamp datetime default NULL,
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  i_online_payment_processor tinyint(3) unsigned NOT NULL default '0',
  merch_acc_password char(64) default NULL,
  merch_acc_login char(64) default NULL,
  reccuring_enabled char(1) NOT NULL default 'N',
  test_mode char(1) NOT NULL default 'Y',
  i_acl int(10) unsigned NOT NULL default '0',
  opening_balance decimal(15,5) NOT NULL default '0.00000',
  min_allowed_payment decimal(15,5) unsigned NOT NULL default '0.00000',
  merch_acc_iso_4217 char(3) default NULL,
  i_lang char(5) default NULL,
  cld_translation_rule char(255) default NULL,
  i_tariff_incoming int(10) unsigned default NULL,
  credit_limit_warning char(25) default NULL,
  callshop_enabled char(1) NOT NULL default 'N',
  billed_to datetime default NULL,
  i_parent int(10) unsigned default NULL,
  i_routing_plan int(10) unsigned default NULL,
  i_vd_plan int(10) unsigned default NULL,
  creation_date datetime default NULL,
  cli_in_translation_rule char(255) default NULL,
  i_moh int(10) unsigned default NULL,
  service_flags char(32) NOT NULL default '',
  i_customer_class int(10) unsigned NOT NULL default '0',
  bp_charge_cc enum('N','Y') default NULL,
  unallocated_payments decimal(15,5) NOT NULL default '0.00000',
  bill_status enum('O','S','C') NOT NULL default 'O',
  PRIMARY KEY  (i_customer),
  UNIQUE KEY customer (name,i_env),
  UNIQUE KEY login (login),
  KEY Customers_acl (i_acl),
  KEY parent_type (i_parent,i_customer_type),
  KEY i_tariff (i_tariff),
  KEY i_tariff_incoming (i_tariff_incoming),
  KEY Customers_iso_4217 (iso_4217),
  KEY i_vd_plan (i_vd_plan),
  KEY i_rep (i_rep),
  KEY i_template (i_template),
  KEY i_customer_class (i_customer_class),
  KEY bill_status (bill_status)
) TYPE=InnoDB;

--
-- Table structure for table `DB_Version`
--

CREATE TABLE DB_Version (
  version char(32) default NULL,
  comment char(100) default NULL,
  rel int(10) unsigned NOT NULL default '0',
  minor int(10) unsigned NOT NULL default '0',
  timestamp datetime default NULL,
  UNIQUE KEY rel_minor (rel,minor)
) TYPE=InnoDB;

--
-- Table structure for table `DID_Numbers`
--

CREATE TABLE DID_Numbers (
  i_did_number int(10) unsigned NOT NULL auto_increment,
  number varchar(32) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_dv_batch int(10) unsigned NOT NULL default '0',
  i_do_batch int(10) default NULL,
  i_account int(10) default NULL,
  reserved datetime default NULL,
  assigned datetime default NULL,
  released datetime default NULL,
  description varchar(255) NOT NULL default '',
  PRIMARY KEY  (i_did_number),
  UNIQUE KEY env_number (i_env,number),
  KEY number (number,i_do_batch)
) TYPE=MyISAM;

--
-- Table structure for table `DID_Owner_Batches`
--

CREATE TABLE DID_Owner_Batches (
  i_do_batch int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_customer int(10) unsigned default NULL,
  description char(255) default NULL,
  PRIMARY KEY  (i_do_batch),
  UNIQUE KEY env_name (i_env,name)
) TYPE=MyISAM;

--
-- Table structure for table `DID_Vendor_Batches`
--

CREATE TABLE DID_Vendor_Batches (
  i_dv_batch int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_vendor int(10) unsigned NOT NULL default '0',
  iso_3166_1_a2 char(2) default NULL,
  area_code char(8) default NULL,
  area_code_description char(64) default NULL,
  description char(255) default NULL,
  PRIMARY KEY  (i_dv_batch),
  UNIQUE KEY env_name (i_env,name)
) TYPE=MyISAM;

--
-- Table structure for table `Destination_Group_Link`
--

CREATE TABLE Destination_Group_Link (
  i_dest_group_link int(10) unsigned NOT NULL auto_increment,
  i_dest_group int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_dest_group_link),
  UNIQUE KEY dest_group_prefix (i_dest_group,i_dest),
  KEY destination (i_dest)
) TYPE=InnoDB;

--
-- Table structure for table `Destination_Group_Sets`
--

CREATE TABLE Destination_Group_Sets (
  i_dest_group_set int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned default '1',
  name char(32) NOT NULL default '',
  PRIMARY KEY  (i_dest_group_set)
) TYPE=InnoDB;

--
-- Table structure for table `Destination_Groups`
--

CREATE TABLE Destination_Groups (
  i_dest_group int(10) unsigned NOT NULL auto_increment,
  i_dest_group_set int(10) unsigned NOT NULL default '0',
  i_env tinyint(1) unsigned default '1',
  name char(100) NOT NULL default '',
  PRIMARY KEY  (i_dest_group),
  UNIQUE KEY destination_group (i_dest_group_set,name),
  KEY destination_set (i_dest_group_set),
  KEY name_set_dest_group (name,i_dest_group_set,i_dest_group)
) TYPE=InnoDB;

--
-- Table structure for table `Destinations`
--

CREATE TABLE Destinations (
  i_dest int(10) unsigned NOT NULL auto_increment,
  destination char(16) NOT NULL default '',
  iso_3166_1_a2 char(2) default '',
  i_country_subdivision smallint(5) unsigned default NULL,
  i_time_zone int(10) unsigned default NULL,
  description char(64) NOT NULL default '',
  i_group int(10) unsigned default '0',
  i_env tinyint(1) unsigned default '1',
  dest_type char(20) default NULL,
  PRIMARY KEY  (i_dest),
  UNIQUE KEY destination (destination,i_env),
  KEY iso_3166_1_a2 (iso_3166_1_a2),
  KEY Destinations_i_group (i_group),
  KEY dest_type (dest_type),
  KEY env_dest_i_dest_iso (destination,i_env,i_dest,iso_3166_1_a2)
) TYPE=InnoDB;

--
-- Table structure for table `Disconnect_Reason_Class`
--

CREATE TABLE Disconnect_Reason_Class (
  i_class tinyint(1) unsigned NOT NULL default '0',
  description char(128) NOT NULL default '',
  PRIMARY KEY  (i_class)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `Disconnect_Reasons`
--

CREATE TABLE Disconnect_Reasons (
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  disconnect_text char(128) NOT NULL default '',
  i_class tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (disconnect_cause)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `Env`
--

CREATE TABLE Env (
  i_env tinyint(1) unsigned NOT NULL auto_increment,
  name char(32) default NULL,
  description char(255) default NULL,
  companyname char(59) default NULL,
  addr1 char(41) default NULL,
  addr2 char(41) default NULL,
  addr3 char(41) default NULL,
  addr4 char(41) default NULL,
  iso_3166_1_a2 char(2) default NULL,
  phone char(51) default NULL,
  faxnum char(51) default NULL,
  email char(99) default NULL,
  web char(128) default NULL,
  lname char(59) default NULL,
  laddr1 char(41) default NULL,
  laddr2 char(41) default NULL,
  lcity char(31) default NULL,
  i_country_subdivision smallint(5) unsigned default NULL,
  lzip char(13) default NULL,
  liso_3166_1_a2 char(2) default NULL,
  tax_id char(16) default NULL,
  iso_4217 char(3) default NULL,
  i_billing_period tinyint(2) unsigned NOT NULL default '4',
  i_time_zone int(10) unsigned NOT NULL default '0',
  calls_counted_time datetime default NULL,
  billed_to datetime default NULL,
  PRIMARY KEY  (i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Follow_Me`
--

CREATE TABLE Follow_Me (
  i_follow_me int(10) unsigned NOT NULL auto_increment,
  i_account int(10) unsigned NOT NULL default '0',
  mode enum('Never','Always','Unavail') default NULL,
  sequence enum('Order','Random','Simultaneous') default NULL,
  timeout smallint(4) unsigned default NULL,
  PRIMARY KEY  (i_follow_me),
  UNIQUE KEY i_account (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `Follow_Me_Numbers`
--

CREATE TABLE Follow_Me_Numbers (
  i_follow_me_number int(10) unsigned NOT NULL auto_increment,
  i_follow_me int(10) unsigned NOT NULL default '0',
  i_account int(10) unsigned NOT NULL default '0',
  i_follow_order int(3) unsigned default NULL,
  name varchar(32) default NULL,
  active char(1) default 'Y',
  period varchar(255) default NULL,
  period_description text,
  redirect_number varchar(32) NOT NULL default '',
  timeout int(2) NOT NULL default '20',
  PRIMARY KEY  (i_follow_me_number),
  UNIQUE KEY i_account (i_account,i_follow_order)
) TYPE=InnoDB;

--
-- Table structure for table `Format_Types`
--

CREATE TABLE Format_Types (
  i_format_type smallint(5) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  PRIMARY KEY  (i_format_type),
  UNIQUE KEY format_type (name)
) TYPE=InnoDB;

--
-- Table structure for table `Formats`
--

CREATE TABLE Formats (
  i_format smallint(5) unsigned NOT NULL auto_increment,
  i_format_type smallint(5) unsigned NOT NULL default '0',
  editor_order smallint(5) unsigned NOT NULL default '0',
  format varchar(128) NOT NULL default '',
  rule_upload text,
  rule_download text,
  PRIMARY KEY  (i_format),
  UNIQUE KEY format (i_format_type,format)
) TYPE=InnoDB;

--
-- Table structure for table `ID`
--

CREATE TABLE ID (
  name char(255) NOT NULL default '',
  id_value int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (name)
) TYPE=InnoDB;

--
-- Table structure for table `Invoice_Status_Attribs`
--

CREATE TABLE Invoice_Status_Attribs (
  i_invoice_status int(10) unsigned NOT NULL auto_increment,
  description char(32) default NULL,
  PRIMARY KEY  (i_invoice_status)
) TYPE=MyISAM;

--
-- Table structure for table `Invoices`
--

CREATE TABLE Invoices (
  i_invoice int(10) unsigned NOT NULL auto_increment,
  invoice_number int(10) unsigned NOT NULL default '0',
  i_customer int(10) unsigned NOT NULL default '0',
  issue_date date NOT NULL default '0000-00-00',
  period_from datetime NOT NULL default '0000-00-00 00:00:00',
  period_to datetime NOT NULL default '0000-00-00 00:00:00',
  i_payment_term int(10) unsigned NOT NULL default '1',
  amount_net decimal(15,5) default '0.00000',
  amount_due decimal(15,5) NOT NULL default '0.00000',
  closed char(1) NOT NULL default 'N',
  i_env tinyint(1) unsigned NOT NULL default '1',
  previous_balance decimal(15,5) default '0.00000',
  payments decimal(15,5) default '0.00000',
  subscriptions decimal(15,5) default '0.00000',
  manual_charges decimal(15,5) default '0.00000',
  taxes decimal(15,5) default '0.00000',
  calls decimal(15,5) default '0.00000',
  new_style tinyint(1) NOT NULL default '0',
  due_date date NOT NULL default '0000-00-00',
  i_invoice_status int(10) unsigned NOT NULL default '0',
  amount_paid decimal(15,5) NOT NULL default '0.00000',
  last_notific_date date default NULL,
  last_resend_date date default NULL,
  last_recollect_date date default NULL,
  last_warning_date date default NULL,
  last_suspension_date date default NULL,
  last_closing_date date default NULL,
  PRIMARY KEY  (i_invoice)
) TYPE=InnoDB;

--
-- Table structure for table `Invoices_backup`
--

CREATE TABLE Invoices_backup (
  i_invoice int(10) unsigned NOT NULL auto_increment,
  invoice_number int(10) unsigned NOT NULL default '0',
  i_customer int(10) unsigned NOT NULL default '0',
  issue_date date NOT NULL default '0000-00-00',
  period_from datetime NOT NULL default '0000-00-00 00:00:00',
  period_to datetime NOT NULL default '0000-00-00 00:00:00',
  i_payment_term int(10) unsigned NOT NULL default '1',
  amount_net decimal(15,5) default '0.00000',
  amount_due decimal(15,5) NOT NULL default '0.00000',
  closed char(1) NOT NULL default 'N',
  i_env tinyint(1) unsigned NOT NULL default '1',
  previous_balance decimal(15,5) default '0.00000',
  payments decimal(15,5) default '0.00000',
  new_style tinyint(1) NOT NULL default '0',
  due_date date NOT NULL default '0000-00-00',
  PRIMARY KEY  (i_invoice)
) TYPE=InnoDB;

--
-- Table structure for table `Languages`
--

CREATE TABLE Languages (
  name char(64) NOT NULL default '',
  iso_639_1 char(5) default NULL,
  iso_639_2b char(3) NOT NULL default '',
  iso_639_2t char(3) NOT NULL default '',
  PRIMARY KEY  (iso_639_2t),
  UNIQUE KEY iso_639_2b (iso_639_2b),
  KEY iso_639_1 (iso_639_1)
) TYPE=InnoDB;

--
-- Table structure for table `Locale_Languages`
--

CREATE TABLE Locale_Languages (
  iso_639_1 char(5) NOT NULL default '',
  css_filename char(64) default NULL,
  PRIMARY KEY  (iso_639_1)
) TYPE=InnoDB;

--
-- Table structure for table `Log`
--

CREATE TABLE Log (
  i_log int(10) unsigned NOT NULL auto_increment,
  log_time timestamp(14) NOT NULL,
  ip char(64) NOT NULL default '',
  table_name char(50) NOT NULL default '',
  line char(10) default NULL,
  comment char(100) NOT NULL default '',
  description char(255) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_user int(10) unsigned NOT NULL default '0',
  parent_key char(10) default NULL,
  parent_table char(50) default NULL,
  realm char(20) default NULL,
  PRIMARY KEY  (i_log),
  UNIQUE KEY Log_index (i_log),
  KEY LogTableLine (table_name,line,i_env),
  KEY LogParent (parent_table,parent_key)
) TYPE=InnoDB;

--
-- Table structure for table `Mail_Alarm_Types`
--

CREATE TABLE Mail_Alarm_Types (
  i_alarm int(10) unsigned NOT NULL auto_increment,
  code char(16) default NULL,
  subject char(255) default NULL,
  PRIMARY KEY  (i_alarm),
  UNIQUE KEY code (code)
) TYPE=InnoDB;

--
-- Table structure for table `Mail_List`
--

CREATE TABLE Mail_List (
  i_alarm int(10) unsigned NOT NULL default '0',
  i_user int(10) unsigned NOT NULL default '0',
  i_mail_list int(10) unsigned NOT NULL auto_increment,
  PRIMARY KEY  (i_mail_list),
  UNIQUE KEY i_alarm_i_user (i_alarm,i_user)
) TYPE=InnoDB;

--
-- Table structure for table `Maintenance_Fee`
--

CREATE TABLE Maintenance_Fee (
  i_account int(10) unsigned NOT NULL default '0',
  last_maintenance_date datetime default NULL,
  first_maintenance_date date default NULL,
  UNIQUE KEY i_account (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `Manual_Transactions`
--

CREATE TABLE Manual_Transactions (
  i_manual_transaction int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned default NULL,
  i_dest int(10) unsigned NOT NULL default '0',
  name varchar(64) NOT NULL default '',
  default_amount varchar(15) default NULL,
  default_comment varchar(32) NOT NULL default '',
  app_to_retail_customer enum('Y','N') NOT NULL default 'Y',
  app_to_wholesale_customer enum('Y','N') NOT NULL default 'Y',
  app_to_vendor enum('Y','N') NOT NULL default 'Y',
  app_to_debit_account enum('Y','N') NOT NULL default 'Y',
  app_to_credit_account enum('Y','N') NOT NULL default 'Y',
  handler varchar(255) default NULL,
  description varchar(32) default NULL,
  destination varchar(15) default NULL,
  PRIMARY KEY  (i_manual_transaction),
  UNIQUE KEY manual_transaction (name)
) TYPE=InnoDB;

--
-- Table structure for table `Media_Attribute_Definitions`
--

CREATE TABLE Media_Attribute_Definitions (
  i_ma_definition smallint(10) unsigned NOT NULL auto_increment,
  i_ma_type smallint(5) unsigned NOT NULL default '0',
  i_media_type smallint(5) unsigned NOT NULL default '0',
  name char(64) NOT NULL default '',
  mandatory char(1) NOT NULL default 'Y',
  PRIMARY KEY  (i_ma_definition),
  UNIQUE KEY mad_name (i_media_type,name)
) TYPE=InnoDB;

--
-- Table structure for table `Media_Attribute_Types`
--

CREATE TABLE Media_Attribute_Types (
  i_ma_type smallint(5) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  PRIMARY KEY  (i_ma_type),
  UNIQUE KEY ma_type (name)
) TYPE=InnoDB;

--
-- Table structure for table `Media_Attribute_Values`
--

CREATE TABLE Media_Attribute_Values (
  i_ma_value int(10) unsigned NOT NULL auto_increment,
  i_ma_definition smallint(10) unsigned NOT NULL default '0',
  value char(64) NOT NULL default '',
  editor_value char(64) NOT NULL default '',
  PRIMARY KEY  (i_ma_value),
  UNIQUE KEY ma_value (i_ma_definition,value),
  UNIQUE KEY ma_editor_value (i_ma_definition,editor_value)
) TYPE=InnoDB;

--
-- Table structure for table `Media_Types`
--

CREATE TABLE Media_Types (
  i_media_type smallint(5) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  icon_url char(255) default NULL,
  PRIMARY KEY  (i_media_type),
  UNIQUE KEY media_type (name),
  UNIQUE KEY media_icon (icon_url)
) TYPE=InnoDB;

--
-- Table structure for table `Merchant_Account_Currency`
--

CREATE TABLE Merchant_Account_Currency (
  i_ma_currency int(10) unsigned NOT NULL auto_increment,
  i_merchant_account int(10) unsigned NOT NULL default '0',
  iso_4217 char(3) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  min_allowed_payment decimal(15,5) unsigned NOT NULL default '0.00000',
  PRIMARY KEY  (i_ma_currency),
  UNIQUE KEY ma_c (i_merchant_account,iso_4217)
) TYPE=InnoDB;

--
-- Table structure for table `Merchant_Account_Payment_Methods`
--

CREATE TABLE Merchant_Account_Payment_Methods (
  i_me_pm int(10) unsigned NOT NULL auto_increment,
  i_merchant_account int(10) unsigned NOT NULL default '0',
  i_payment_method smallint(5) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_me_pm),
  UNIQUE KEY me_pm (i_merchant_account,i_payment_method)
) TYPE=InnoDB;

--
-- Table structure for table `Merchant_Accounts`
--

CREATE TABLE Merchant_Accounts (
  i_merchant_account int(10) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  i_online_payment_processor tinyint(3) unsigned NOT NULL default '0',
  login char(64) NOT NULL default '',
  password char(64) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  reccuring_enabled char(1) NOT NULL default 'N',
  test_mode char(1) NOT NULL default 'Y',
  i_customer int(10) unsigned default NULL,
  PRIMARY KEY  (i_merchant_account),
  UNIQUE KEY merchant_account_name (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Music_On_Hold`
--

CREATE TABLE Music_On_Hold (
  i_moh int(10) unsigned NOT NULL auto_increment,
  i_env int(10) unsigned default '1',
  object enum('account','customer') default NULL,
  i_object int(10) unsigned default NULL,
  name char(64) NOT NULL default '',
  converted enum('N','Y') NOT NULL default 'N',
  tries tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (i_moh),
  KEY env_object (i_env,object,i_object),
  KEY converted (converted,i_moh)
) TYPE=InnoDB;

--
-- Table structure for table `Node_Notepad`
--

CREATE TABLE Node_Notepad (
  i_node int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_node)
) TYPE=InnoDB;

--
-- Table structure for table `Node_Types`
--

CREATE TABLE Node_Types (
  i_node_type int(10) unsigned NOT NULL auto_increment,
  manufacturer char(32) NOT NULL default '',
  type char(32) NOT NULL default '',
  radius_dictionary char(128) default NULL,
  PRIMARY KEY  (i_node_type),
  UNIQUE KEY type_manufacturer (type,manufacturer)
) TYPE=InnoDB;

--
-- Table structure for table `Nodes`
--

CREATE TABLE Nodes (
  i_node int(10) unsigned NOT NULL auto_increment,
  ip char(64) NOT NULL default '',
  h323_id char(255) NOT NULL default '',
  name char(41) default NULL,
  type enum('VOIP-GW','H323-GW','H323-GK','TERM','MCU','SIP Server','MVTS') default 'VOIP-GW',
  radius_client char(1) NOT NULL default 'N',
  radius_key char(32) default NULL,
  i_env tinyint(1) unsigned default '1',
  hostname char(255) default NULL,
  domain char(255) default NULL,
  manufacturer enum('Cisco','Quintum') default 'Cisco',
  i_time_zone int(10) unsigned NOT NULL default '1',
  h323_password char(255) default NULL,
  cld_translation_rule char(255) default NULL,
  radius_source_ip char(64) default NULL,
  id char(32) default NULL,
  i_node_type int(10) unsigned default NULL,
  rtpp_level tinyint(1) unsigned default NULL,
  PRIMARY KEY  (i_node),
  UNIQUE KEY ip (ip),
  UNIQUE KEY h323_id (h323_id),
  UNIQUE KEY node (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `OLI_Values`
--

CREATE TABLE OLI_Values (
  i_oli int(10) unsigned NOT NULL auto_increment,
  oli tinyint(2) unsigned NOT NULL default '0',
  description char(127) NOT NULL default '',
  PRIMARY KEY  (i_oli),
  UNIQUE KEY oli (oli),
  UNIQUE KEY oli_description (description)
) TYPE=InnoDB;

--
-- Table structure for table `Online_Payment_Processors`
--

CREATE TABLE Online_Payment_Processors (
  i_online_payment_processor tinyint(3) unsigned NOT NULL auto_increment,
  processor char(64) NOT NULL default '',
  web_link char(255) NOT NULL default '',
  handler char(100) default NULL,
  callback char(100) default NULL,
  ext_auth char(1) NOT NULL default 'N',
  PRIMARY KEY  (i_online_payment_processor),
  UNIQUE KEY processor_index (processor)
) TYPE=InnoDB;

--
-- Table structure for table `Payment_Methods`
--

CREATE TABLE Payment_Methods (
  i_payment_method smallint(5) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  name char(31) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  online char(1) default 'Y',
  icon_url char(255) default NULL,
  payment_method char(32) default NULL,
  ecommerce enum('Y','N') NOT NULL default 'Y',
  PRIMARY KEY  (i_payment_method),
  UNIQUE KEY pm_name (name)
) TYPE=InnoDB;

--
-- Table structure for table `Payment_Terms`
--

CREATE TABLE Payment_Terms (
  i_payment_term int(10) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  name char(31) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  discc_per decimal(9,5) NOT NULL default '0.00000',
  std_due_days smallint(6) default NULL,
  std_disc_days smallint(6) default NULL,
  day_of_month_due smallint(6) default NULL,
  disc_day_of_month smallint(6) default NULL,
  date_min_days smallint(6) default NULL,
  terms_type smallint(6) default NULL,
  hidden char(1) NOT NULL default 'N',
  i_env tinyint(1) default '1',
  default_term enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (i_payment_term),
  UNIQUE KEY term_name (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Payment_Transactions`
--

CREATE TABLE Payment_Transactions (
  i_payment_transaction int(10) unsigned NOT NULL auto_increment,
  i_merchant_account int(10) unsigned default NULL,
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  secret char(64) NOT NULL default '',
  i_account int(10) unsigned default NULL,
  i_customer int(10) default NULL,
  amount decimal(15,5) default NULL,
  test_mode char(1) NOT NULL default 'Y',
  iso_4217 char(3) NOT NULL default '',
  status char(16) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  cdrid int(10) unsigned default NULL,
  x_transaction_id char(32) default NULL,
  PRIMARY KEY  (i_payment_transaction)
) TYPE=InnoDB;

--
-- Table structure for table `Periodical_Payments`
--

CREATE TABLE Periodical_Payments (
  i_periodical_payment int(10) unsigned NOT NULL auto_increment,
  i_object int(10) unsigned default NULL,
  i_periodical_payment_period tinyint(2) unsigned NOT NULL default '0',
  amount decimal(9,5) NOT NULL default '0.00000',
  balance_threshold decimal(9,5) NOT NULL default '0.00000',
  from_date date NOT NULL default '0000-00-00',
  to_date date NOT NULL default '0000-00-00',
  discontinued char(1) NOT NULL default 'N',
  i_env tinyint(1) unsigned NOT NULL default '1',
  stamp timestamp(14) NOT NULL,
  last_payment date default NULL,
  frozen char(1) default NULL,
  object enum('account','customer') default NULL,
  PRIMARY KEY  (i_periodical_payment),
  KEY Periodical_Payments_from (from_date),
  KEY Periodical_Payments_i_obj (i_object,object,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Periodical_Payments_Period`
--

CREATE TABLE Periodical_Payments_Period (
  i_periodical_payment_period tinyint(2) unsigned NOT NULL auto_increment,
  description char(32) NOT NULL default '',
  PRIMARY KEY  (i_periodical_payment_period)
) TYPE=InnoDB;

--
-- Table structure for table `Preffered_X_Rate_Source`
--

CREATE TABLE Preffered_X_Rate_Source (
  i_pxr_source int(10) unsigned NOT NULL auto_increment,
  i_x_rate_source smallint(5) unsigned default '2',
  iso_4217 char(3) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (i_pxr_source),
  UNIQUE KEY pxr_s (i_x_rate_source,iso_4217,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Procedures`
--

CREATE TABLE Procedures (
  id int(10) unsigned NOT NULL auto_increment,
  type char(1) default NULL,
  name char(255) default NULL,
  description char(255) default NULL,
  PRIMARY KEY  (id)
) TYPE=InnoDB;

--
-- Table structure for table `Product_Notepad`
--

CREATE TABLE Product_Notepad (
  i_product int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_product)
) TYPE=InnoDB;

--
-- Table structure for table `Product_Subscriptions`
--

CREATE TABLE Product_Subscriptions (
  i_product_subscription int(10) unsigned NOT NULL auto_increment,
  i_product int(10) unsigned NOT NULL default '0',
  i_subscription int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_product_subscription),
  UNIQUE KEY product_subscription (i_product,i_subscription)
) TYPE=MyISAM;

--
-- Table structure for table `Products`
--

CREATE TABLE Products (
  i_product int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  iso_4217 char(3) NOT NULL default '',
  maintenance_fee decimal(15,5) unsigned default '0.00000',
  maintenance_period enum('None','Daily','Weekly','Bi-weekly','Monthly') default 'None',
  maintenance_effective_from date default NULL,
  breakage decimal(15,5) unsigned default '0.00000',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_customer int(10) default NULL,
  description char(255) default NULL,
  info_url char(255) default NULL,
  validation_module char(255) default NULL,
  continue_url char(255) default NULL,
  subscription_http_referer char(255) default NULL,
  subscription_host char(255) default NULL,
  default_i_acl int(10) unsigned NOT NULL default '155',
  i_vd_plan int(10) unsigned default NULL,
  PRIMARY KEY  (i_product),
  UNIQUE KEY product (name,i_env),
  KEY Products_iso_4217 (iso_4217),
  KEY i_vd_plan (i_vd_plan)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `Rates`
--

CREATE TABLE Rates (
  i_tariff int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  i_rate int(10) unsigned NOT NULL auto_increment,
  interval_1 smallint(5) unsigned NOT NULL default '1',
  interval_n smallint(5) unsigned NOT NULL default '1',
  price_1 decimal(15,5) unsigned default NULL,
  price_n decimal(15,5) unsigned default NULL,
  op_interval_1 smallint(5) unsigned NOT NULL default '1',
  op_interval_n smallint(5) unsigned NOT NULL default '1',
  op_price_1 decimal(15,5) unsigned default NULL,
  op_price_n decimal(15,5) unsigned default NULL,
  effective_from datetime NOT NULL default '0000-00-00 00:00:00',
  hidden char(1) NOT NULL default 'N',
  discontinued char(1) NOT NULL default 'N',
  forbidden char(1) NOT NULL default 'N',
  preference tinyint(1) unsigned NOT NULL default '5',
  huntstop char(1) NOT NULL default 'N',
  lot_time int(10) default NULL,
  formula varchar(255) default NULL,
  fake_rate char(1) NOT NULL default 'Y',
  i_master_rate int(10) unsigned default NULL,
  route_category tinyint(1) unsigned default NULL,
  op_route_category tinyint(1) unsigned default NULL,
  op_preference tinyint(1) unsigned default NULL,
  op_huntstop char(1) default 'N',
  PRIMARY KEY  (i_rate),
  KEY Rates_dest_index (i_dest),
  KEY Rates_i_tariff (i_tariff),
  KEY Rates_effective_from (effective_from),
  KEY master_rate (i_master_rate),
  KEY Rates_route_category (route_category,op_route_category),
  KEY tar_dest_effrom_rate (i_tariff,i_dest,effective_from,discontinued,i_rate)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `ReplicationTest`
--

CREATE TABLE ReplicationTest (
  id char(21) default NULL,
  KEY idRepl (id)
) TYPE=InnoDB;

--
-- Table structure for table `Representative_Notepad`
--

CREATE TABLE Representative_Notepad (
  i_rep int(10) unsigned NOT NULL default '0',
  notepad text,
  PRIMARY KEY  (i_rep)
) TYPE=InnoDB;

--
-- Table structure for table `Representatives`
--

CREATE TABLE Representatives (
  i_rep int(10) unsigned NOT NULL auto_increment,
  refnum varchar(32) default NULL,
  initials varchar(5) NOT NULL default '',
  name varchar(41) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  iso_4217 char(3) NOT NULL default '',
  companyname varchar(41) NOT NULL default '',
  salutation varchar(15) NOT NULL default '',
  firstname varchar(25) NOT NULL default '',
  midinit varchar(5) NOT NULL default '',
  lastname varchar(25) NOT NULL default '',
  baddr1 varchar(41) NOT NULL default '',
  baddr2 varchar(41) NOT NULL default '',
  baddr3 varchar(41) NOT NULL default '',
  baddr4 varchar(41) NOT NULL default '',
  baddr5 varchar(41) NOT NULL default '',
  city varchar(31) NOT NULL default '',
  state varchar(21) NOT NULL default '',
  zip varchar(13) NOT NULL default '',
  country varchar(31) NOT NULL default '',
  cont1 varchar(41) NOT NULL default '',
  phone1 varchar(21) NOT NULL default '',
  faxnum varchar(21) NOT NULL default '',
  phone2 varchar(21) NOT NULL default '',
  cont2 varchar(41) NOT NULL default '',
  email varchar(99) default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  i_env tinyint(1) unsigned NOT NULL default '1',
  tax_id varchar(16) default NULL,
  hidden char(1) NOT NULL default 'N',
  i_customer int(10) unsigned default NULL,
  login varchar(16) default NULL,
  password varchar(16) default NULL,
  password_timestamp datetime default NULL,
  i_lang varchar(5) default NULL,
  i_acl int(10) unsigned NOT NULL default '0',
  out_date_format varchar(16) NOT NULL default '',
  out_time_format varchar(16) NOT NULL default '',
  out_date_time_format varchar(32) NOT NULL default '',
  in_date_format varchar(16) NOT NULL default '',
  in_time_format varchar(16) NOT NULL default '',
  PRIMARY KEY  (i_rep),
  UNIQUE KEY login (login),
  KEY env_name (i_env,name),
  KEY i_customer (i_customer)
) TYPE=InnoDB;

--
-- Table structure for table `Route_Categories`
--

CREATE TABLE Route_Categories (
  i_route_category int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned default NULL,
  name char(32) NOT NULL default '',
  description char(255) default NULL,
  PRIMARY KEY  (i_route_category),
  UNIQUE KEY i_env (i_env,i_route_category),
  UNIQUE KEY i_env_2 (i_env,name)
) TYPE=InnoDB;

--
-- Table structure for table `Routing_Plan_Categories`
--

CREATE TABLE Routing_Plan_Categories (
  i_routing_plan_cat int(10) unsigned NOT NULL auto_increment,
  i_routing_plan int(10) unsigned NOT NULL default '0',
  i_route_category_order tinyint(1) NOT NULL default '0',
  i_route_category int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_routing_plan_cat),
  UNIQUE KEY i_routing_plan (i_routing_plan,i_route_category)
) TYPE=InnoDB;

--
-- Table structure for table `Routing_Plans`
--

CREATE TABLE Routing_Plans (
  i_routing_plan int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned default NULL,
  name char(32) NOT NULL default '',
  description char(255) default NULL,
  profit_guarantee char(1) NOT NULL default 'N',
  profit_monitor char(1) NOT NULL default 'N',
  PRIMARY KEY  (i_routing_plan),
  UNIQUE KEY i_env (i_env,name)
) TYPE=InnoDB;

--
-- Table structure for table `Service_Attribute_Values`
--

CREATE TABLE Service_Attribute_Values (
  i_savalue int(10) NOT NULL auto_increment,
  i_sattribute int(10) NOT NULL default '0',
  i_foreign int(10) NOT NULL default '0',
  value char(255) default NULL,
  ord tinyint(4) default NULL,
  PRIMARY KEY  (i_savalue),
  KEY savalue_sattribute (i_sattribute,i_foreign)
) TYPE=MyISAM;

--
-- Table structure for table `Service_Attributes`
--

CREATE TABLE Service_Attributes (
  i_sattribute int(10) NOT NULL auto_increment,
  name char(41) NOT NULL default '',
  i_service int(10) NOT NULL default '0',
  multivalue char(1) NOT NULL default 'N',
  default_value char(255) default NULL,
  PRIMARY KEY  (i_sattribute),
  UNIQUE KEY saname (i_service,name)
) TYPE=MyISAM;

--
-- Table structure for table `Services`
--

CREATE TABLE Services (
  i_service int(10) NOT NULL auto_increment,
  name char(41) NOT NULL default '',
  level enum('Accounts','Customers','Products') NOT NULL default 'Accounts',
  flag_pos tinyint(4) default NULL,
  PRIMARY KEY  (i_service),
  UNIQUE KEY service_name (name,level,flag_pos)
) TYPE=MyISAM;

--
-- Table structure for table `Subscribers`
--

CREATE TABLE Subscribers (
  i_subscriber int(10) unsigned NOT NULL auto_increment,
  companyname char(41) NOT NULL default '',
  salutation char(15) NOT NULL default '',
  firstname char(25) NOT NULL default '',
  midinit char(5) NOT NULL default '',
  lastname char(25) NOT NULL default '',
  baddr1 char(41) NOT NULL default '',
  baddr2 char(41) NOT NULL default '',
  baddr3 char(41) NOT NULL default '',
  baddr4 char(41) NOT NULL default '',
  baddr5 char(41) NOT NULL default '',
  city char(31) NOT NULL default '',
  state char(21) NOT NULL default '',
  zip char(13) NOT NULL default '',
  country char(31) NOT NULL default '',
  note char(41) NOT NULL default '',
  cont1 char(41) NOT NULL default '',
  phone1 char(21) NOT NULL default '',
  faxnum char(21) NOT NULL default '',
  phone2 char(21) NOT NULL default '',
  cont2 char(41) NOT NULL default '',
  email char(99) default NULL,
  bcc char(99) default NULL,
  summary_only char(1) NOT NULL default 'N',
  i_credit_card int(10) unsigned default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (i_subscriber)
) TYPE=InnoDB;

--
-- Table structure for table `Subscription_Fees`
--

CREATE TABLE Subscription_Fees (
  i_subscription_fee int(10) unsigned NOT NULL auto_increment,
  i_subscription int(10) unsigned NOT NULL default '0',
  i_billing_period tinyint(2) unsigned NOT NULL default '0',
  periods smallint(4) unsigned NOT NULL default '0',
  fee decimal(15,5) unsigned NOT NULL default '0.00000',
  PRIMARY KEY  (i_subscription_fee),
  UNIQUE KEY subscription_period (i_subscription,i_billing_period,periods)
) TYPE=MyISAM;

--
-- Table structure for table `Subscriptions`
--

CREATE TABLE Subscriptions (
  i_subscription int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_customer int(10) unsigned default NULL,
  description char(255) default NULL,
  invoice_description char(32) NOT NULL default '',
  iso_4217 char(3) NOT NULL default '',
  activation_mode tinyint(1) unsigned NOT NULL default '1',
  activation_fee decimal(15,5) unsigned default NULL,
  minimum_period smallint(4) unsigned default NULL,
  cancel_penalty decimal(15,5) unsigned default NULL,
  charge_model tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (i_subscription),
  UNIQUE KEY env_name (i_env,name)
) TYPE=MyISAM;

--
-- Table structure for table `Tariff_Notepad`
--

CREATE TABLE Tariff_Notepad (
  i_tariff int(10) unsigned NOT NULL auto_increment,
  notepad text,
  off_peak_description text,
  PRIMARY KEY  (i_tariff)
) TYPE=InnoDB;

--
-- Table structure for table `Tariff_Template_Binding`
--

CREATE TABLE Tariff_Template_Binding (
  i_ttb int(10) unsigned NOT NULL auto_increment,
  i_tariff_template int(10) unsigned NOT NULL default '0',
  i_tariff int(10) unsigned NOT NULL default '0',
  email_from char(128) NOT NULL default '',
  email_key char(128) default NULL,
  disabled char(1) NOT NULL default 'Y',
  i_env tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (i_ttb),
  UNIQUE KEY ttb (i_tariff_template,i_tariff,email_from)
) TYPE=InnoDB;

--
-- Table structure for table `Tariffs`
--

CREATE TABLE Tariffs (
  i_tariff int(10) unsigned NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  period varchar(255) default NULL,
  currency char(3) NOT NULL default '',
  free_sec smallint(5) unsigned default '0',
  connect_fee decimal(15,5) unsigned NOT NULL default '0.00000',
  login_fee decimal(15,5) unsigned NOT NULL default '0.00000',
  i_env int(1) unsigned NOT NULL default '1',
  description varchar(255) NOT NULL default '',
  post_call_surcharge decimal(9,5) unsigned NOT NULL default '0.00000',
  i_tariff_template_upload int(10) unsigned default NULL,
  i_tariff_template_download int(10) unsigned default NULL,
  i_customer int(10) default NULL,
  short_description varchar(32) NOT NULL default '',
  routing_ext char(1) NOT NULL default 'N',
  volume_based char(1) default 'N',
  i_dest_group_set int(10) unsigned default NULL,
  rounding smallint(5) default NULL,
  formula varchar(255) default NULL,
  rating_mode enum('Standard','Fixed') default 'Standard',
  PRIMARY KEY  (i_tariff),
  UNIQUE KEY tariff (name,i_env),
  KEY i_tariff_template_upload (i_tariff_template_upload),
  KEY i_tariff_template_download (i_tariff_template_download)
) TYPE=InnoDB PACK_KEYS=1;

--
-- Table structure for table `TasksStack`
--

CREATE TABLE TasksStack (
  id int(10) unsigned NOT NULL auto_increment,
  insert_time datetime default NULL,
  i_user int(11) default NULL,
  complete char(1) default NULL,
  i_proc int(10) unsigned default NULL,
  data text,
  start_time datetime default NULL,
  dependent_task bigint(20) unsigned default NULL,
  reenter bigint(20) unsigned default NULL,
  reenter_id varchar(32) default NULL,
  email enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (id)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Components`
--

CREATE TABLE Template_Components (
  i_template_component int(10) unsigned NOT NULL auto_increment,
  i_template int(10) unsigned NOT NULL default '0',
  i_component_type smallint(5) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_template_component)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Data_Fields`
--

CREATE TABLE Template_Data_Fields (
  i_td_field int(10) unsigned NOT NULL auto_increment,
  i_template int(10) unsigned NOT NULL default '0',
  i_component_type smallint(5) unsigned NOT NULL default '0',
  editor_order tinyint(3) unsigned NOT NULL default '0',
  editor_name varchar(64) NOT NULL default '',
  target_db_field varchar(255) default NULL,
  source_db_field varchar(255) default NULL,
  document_order tinyint(3) unsigned default '1',
  i_format_type smallint(5) unsigned NOT NULL default '0',
  i_format smallint(5) unsigned NOT NULL default '0',
  rule text,
  pp_rule text,
  sample_data varchar(255) default NULL,
  symbolic_id varchar(64) NOT NULL default '',
  sql_expr varchar(255) default NULL,
  PRIMARY KEY  (i_td_field),
  UNIQUE KEY editor_order (i_td_field,i_component_type,editor_order)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Data_Group_Break`
--

CREATE TABLE Template_Data_Group_Break (
  i_tdgb int(10) unsigned NOT NULL auto_increment,
  i_tdg int(10) unsigned NOT NULL default '0',
  break_order tinyint(3) NOT NULL default '0',
  direction enum('ASC','DESC') NOT NULL default 'ASC',
  break_expr varchar(255) NOT NULL default '',
  PRIMARY KEY  (i_tdgb),
  KEY break_order (i_tdg,break_order)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Data_Groups`
--

CREATE TABLE Template_Data_Groups (
  i_tdg int(10) NOT NULL auto_increment,
  i_template int(10) unsigned NOT NULL default '0',
  name varchar(32) NOT NULL default '',
  group_order tinyint(5) NOT NULL default '0',
  PRIMARY KEY  (i_tdg),
  KEY Template (i_template,group_order)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Group_Fields`
--

CREATE TABLE Template_Group_Fields (
  i_tg_field int(10) unsigned NOT NULL auto_increment,
  i_tdg int(10) unsigned NOT NULL default '0',
  editor_order tinyint(3) unsigned NOT NULL default '0',
  editor_name varchar(64) NOT NULL default '',
  target_db_field varchar(255) default NULL,
  source_db_field varchar(255) default NULL,
  document_order tinyint(3) unsigned default '1',
  i_format_type smallint(5) unsigned NOT NULL default '0',
  i_format smallint(5) unsigned NOT NULL default '0',
  rule text,
  pp_rule text,
  total_rule text,
  sample_data varchar(255) default NULL,
  symbolic_id varchar(64) NOT NULL default '',
  type enum('Group Header','Group Footer') NOT NULL default 'Group Header',
  PRIMARY KEY  (i_tg_field),
  UNIQUE KEY editor_order (i_tdg,type,editor_order)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Media_Attributes`
--

CREATE TABLE Template_Media_Attributes (
  i_tma int(10) unsigned NOT NULL auto_increment,
  i_template int(10) unsigned NOT NULL default '0',
  i_ma_definition smallint(10) unsigned NOT NULL default '0',
  editor_order tinyint(3) unsigned NOT NULL default '0',
  value char(64) default NULL,
  editable char(1) NOT NULL default 'Y',
  hidden char(1) NOT NULL default 'N',
  PRIMARY KEY  (i_tma)
) TYPE=InnoDB;

--
-- Table structure for table `Template_Types`
--

CREATE TABLE Template_Types (
  i_template_type smallint(5) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  dataflow char(64) default NULL,
  hidden char(1) NOT NULL default 'N',
  groups_enabled char(1) NOT NULL default 'N',
  PRIMARY KEY  (i_template_type),
  UNIQUE KEY temp_type (name)
) TYPE=InnoDB;

--
-- Table structure for table `Templates`
--

CREATE TABLE Templates (
  i_template int(10) unsigned NOT NULL auto_increment,
  i_template_type smallint(5) unsigned NOT NULL default '0',
  i_media_type smallint(5) unsigned NOT NULL default '0',
  name char(64) NOT NULL default '',
  i_env tinyint(1) unsigned default '1',
  i_time_zone int(10) unsigned default NULL,
  is_default char(1) NOT NULL default 'N',
  i_customer int(10) unsigned default NULL,
  PRIMARY KEY  (i_template),
  UNIQUE KEY templates (name,i_env),
  KEY env_type_name (i_env,i_template_type,name)
) TYPE=InnoDB;

--
-- Table structure for table `Time_Zones`
--

CREATE TABLE Time_Zones (
  i_time_zone int(10) unsigned NOT NULL auto_increment,
  iso_3166_1_a2 char(2) NOT NULL default '',
  TZ char(64) NOT NULL default '',
  comments char(255) NOT NULL default '',
  format char(64) NOT NULL default '',
  PRIMARY KEY  (i_time_zone),
  UNIQUE KEY TZ (TZ)
) TYPE=InnoDB;

--
-- Table structure for table `UA`
--

CREATE TABLE UA (
  i_ua int(10) unsigned NOT NULL auto_increment,
  name varchar(50) NOT NULL default '',
  i_ua_type int(10) unsigned NOT NULL default '0',
  mac varchar(17) default NULL,
  i_customer int(10) unsigned default NULL,
  i_env tinyint(1) unsigned default '1',
  ua_profile_id int(10) unsigned default NULL,
  description varchar(255) default NULL,
  ascii_key varchar(128) NOT NULL default '',
  inventory_id varchar(128) default NULL,
  used tinyint(2) NOT NULL default '0',
  PRIMARY KEY  (i_ua),
  UNIQUE KEY mac_env (mac,i_env),
  UNIQUE KEY name_env (name,i_env),
  KEY profile_id (ua_profile_id)
) TYPE=InnoDB;

--
-- Table structure for table `UA_Links`
--

CREATE TABLE UA_Links (
  i_ua_link int(10) unsigned NOT NULL auto_increment,
  i_account int(10) unsigned default NULL,
  i_ua int(10) unsigned default NULL,
  port int(10) unsigned default NULL,
  ua_profile_id int(10) default NULL,
  PRIMARY KEY  (i_ua_link),
  UNIQUE KEY account_ua_port (i_account,i_ua,port),
  KEY i_ua (i_ua),
  KEY i_account (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `UA_Notepad`
--

CREATE TABLE UA_Notepad (
  i_ua int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_ua)
) TYPE=InnoDB;

--
-- Table structure for table `UA_Profile_Notepad`
--

CREATE TABLE UA_Profile_Notepad (
  i_ua_profile int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_ua_profile)
) TYPE=InnoDB;

--
-- Table structure for table `UA_Profile_Values`
--

CREATE TABLE UA_Profile_Values (
  i_ua_profile_value int(10) unsigned NOT NULL auto_increment,
  i_ua_profile int(10) unsigned default NULL,
  name varchar(255) NOT NULL default '',
  value varchar(255) NOT NULL default '',
  PRIMARY KEY  (i_ua_profile_value)
) TYPE=InnoDB;

--
-- Table structure for table `UA_Profiles`
--

CREATE TABLE UA_Profiles (
  i_ua_profile int(10) unsigned NOT NULL auto_increment,
  i_env int(10) unsigned default NULL,
  i_ua_type int(10) unsigned default NULL,
  name varchar(32) NOT NULL default '',
  description varchar(255) NOT NULL default '',
  effective_from datetime NOT NULL default '0000-00-00 00:00:00',
  discontinued char(1) default 'N',
  ua_profile_id int(10) NOT NULL default '0',
  i_customer int(10) unsigned default NULL,
  PRIMARY KEY  (i_ua_profile),
  KEY ua_profile_name_id (name,ua_profile_id)
) TYPE=InnoDB;

--
-- Table structure for table `UA_Types`
--

CREATE TABLE UA_Types (
  i_ua_type int(10) unsigned NOT NULL auto_increment,
  manufacturer char(20) NOT NULL default '',
  product char(10) default NULL,
  version char(10) default NULL,
  ports smallint(5) unsigned default NULL,
  type_id tinyint(2) unsigned default NULL,
  PRIMARY KEY  (i_ua_type),
  UNIQUE KEY manuf_code_vesion (manufacturer,product,version)
) TYPE=InnoDB;

--
-- Table structure for table `UM_Account_Status`
--

CREATE TABLE UM_Account_Status (
  i_account int(10) NOT NULL default '0',
  unread_msg_notifed char(1) default NULL,
  call_id varchar(255) default NULL,
  unread_msg_present char(1) default NULL,
  id varchar(32) default NULL,
  PRIMARY KEY  (i_account)
) TYPE=InnoDB;

--
-- Table structure for table `UpdateTickets`
--

CREATE TABLE UpdateTickets (
  ticket char(32) NOT NULL default '',
  stamp datetime default NULL,
  PRIMARY KEY  (ticket),
  KEY stamp (stamp)
) TYPE=InnoDB;

--
-- Table structure for table `User_Name_Replacement`
--

CREATE TABLE User_Name_Replacement (
  i_un_replacement int(10) unsigned NOT NULL auto_increment,
  i_node int(10) unsigned NOT NULL default '0',
  i_un_replacement_rule int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_un_replacement),
  UNIQUE KEY rule (i_node,i_un_replacement_rule)
) TYPE=InnoDB;

--
-- Table structure for table `User_Name_Replacement_Rules`
--

CREATE TABLE User_Name_Replacement_Rules (
  i_un_replacement_rule int(10) unsigned NOT NULL auto_increment,
  type enum('VoIP','Telephony') NOT NULL default 'VoIP',
  name char(32) NOT NULL default '',
  description char(64) NOT NULL default '',
  rule char(255) NOT NULL default '',
  call_origin enum('answer','originate','*') default 'answer',
  call_type enum('Telephony','VoIP','*') default NULL,
  PRIMARY KEY  (i_un_replacement_rule),
  UNIQUE KEY rule (name)
) TYPE=InnoDB;

--
-- Table structure for table `User_Notepad`
--

CREATE TABLE User_Notepad (
  i_user int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_user)
) TYPE=InnoDB;

--
-- Table structure for table `Users`
--

CREATE TABLE Users (
  i_user int(10) unsigned NOT NULL auto_increment,
  login char(32) NOT NULL default '',
  password char(32) NOT NULL default '',
  i_access_level int(10) unsigned NOT NULL default '5',
  description char(128) NOT NULL default '',
  email char(128) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  activation_date date NOT NULL default '0000-00-00',
  expiration_date date default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  password_timestamp datetime default NULL,
  old_passwords char(61) default NULL,
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  i_acl int(10) unsigned NOT NULL default '0',
  i_lang char(5) default NULL,
  companyname char(41) NOT NULL default '',
  salutation char(15) NOT NULL default '',
  firstname char(25) NOT NULL default '',
  midinit char(5) NOT NULL default '',
  lastname char(25) NOT NULL default '',
  baddr1 char(41) NOT NULL default '',
  baddr2 char(41) NOT NULL default '',
  baddr3 char(41) NOT NULL default '',
  baddr4 char(41) NOT NULL default '',
  baddr5 char(41) NOT NULL default '',
  city char(31) NOT NULL default '',
  state char(21) NOT NULL default '',
  zip char(13) NOT NULL default '',
  country char(31) NOT NULL default '',
  cont1 char(41) NOT NULL default '',
  phone1 char(21) NOT NULL default '',
  faxnum char(21) NOT NULL default '',
  phone2 char(21) NOT NULL default '',
  cont2 char(41) NOT NULL default '',
  PRIMARY KEY  (i_user),
  UNIQUE KEY users_login_index (login),
  KEY Users_env (i_env),
  KEY Users_acl (i_acl)
) TYPE=InnoDB;

--
-- Table structure for table `Vendor_Accounts`
--

CREATE TABLE Vendor_Accounts (
  i_vendor_acc int(10) unsigned NOT NULL auto_increment,
  name char(64) NOT NULL default '',
  login char(64) NOT NULL default '',
  password char(64) NOT NULL default '',
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_vendor int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_vendor_acc),
  UNIQUE KEY vendor_account_name (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `Vendor_Notepad`
--

CREATE TABLE Vendor_Notepad (
  i_vendor int(10) unsigned NOT NULL auto_increment,
  notepad text,
  PRIMARY KEY  (i_vendor)
) TYPE=InnoDB;

--
-- Table structure for table `Vendors`
--

CREATE TABLE Vendors (
  i_vendor int(10) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  name char(41) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  balance decimal(15,5) NOT NULL default '0.00000',
  iso_4217 char(3) NOT NULL default '',
  companyname char(41) NOT NULL default '',
  salutation char(15) NOT NULL default '',
  firstname char(25) NOT NULL default '',
  midinit char(5) NOT NULL default '',
  lastname char(25) NOT NULL default '',
  baddr1 char(41) NOT NULL default '',
  baddr2 char(41) NOT NULL default '',
  baddr3 char(41) NOT NULL default '',
  baddr4 char(41) NOT NULL default '',
  baddr5 char(41) NOT NULL default '',
  city char(31) NOT NULL default '',
  state char(21) NOT NULL default '',
  zip char(13) NOT NULL default '',
  country char(31) NOT NULL default '',
  note char(41) NOT NULL default '',
  cont1 char(41) NOT NULL default '',
  phone1 char(21) NOT NULL default '',
  faxnum char(21) NOT NULL default '',
  phone2 char(21) NOT NULL default '',
  cont2 char(41) NOT NULL default '',
  email char(99) default NULL,
  bcc char(99) default NULL,
  send_statistics char(1) NOT NULL default 'N',
  i_time_zone int(10) unsigned NOT NULL default '1',
  i_billing_period tinyint(2) unsigned NOT NULL default '0',
  i_env tinyint(1) unsigned NOT NULL default '1',
  login char(16) default NULL,
  password char(16) default NULL,
  opening_balance decimal(15,5) NOT NULL default '0.00000',
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  i_acl int(10) unsigned NOT NULL default '0',
  password_timestamp datetime default NULL,
  i_lang char(5) default NULL,
  billed_to datetime default NULL,
  asr_report_calculated datetime default NULL,
  i_customer int(10) unsigned default NULL,
  offset_threshold decimal(15,5) default NULL,
  PRIMARY KEY  (i_vendor),
  UNIQUE KEY vendor (name,i_env),
  UNIQUE KEY login (login),
  KEY Vendors_iso_4217 (iso_4217),
  KEY i_customer (i_customer)
) TYPE=InnoDB;

--
-- Table structure for table `Volume_Discount_Destination_Groups`
--

CREATE TABLE Volume_Discount_Destination_Groups (
  i_vd_dg int(10) unsigned NOT NULL auto_increment,
  i_vd_plan int(10) unsigned NOT NULL default '0',
  i_dest_group int(10) unsigned NOT NULL default '0',
  threshold_type enum('Charged Amount','Charged Time') NOT NULL default 'Charged Amount',
  PRIMARY KEY  (i_vd_dg)
) TYPE=InnoDB;

--
-- Table structure for table `Volume_Discount_Plans`
--

CREATE TABLE Volume_Discount_Plans (
  i_vd_plan int(10) unsigned NOT NULL auto_increment,
  i_env int(10) unsigned NOT NULL default '0',
  name char(32) NOT NULL default '',
  description char(255) default NULL,
  i_dest_group_set int(10) unsigned NOT NULL default '0',
  currency char(3) NOT NULL default '',
  i_customer int(10) unsigned default NULL,
  reset_period enum('Never','Billing-period') default NULL,
  PRIMARY KEY  (i_vd_plan)
) TYPE=InnoDB;

--
-- Table structure for table `Volume_Discount_Thresholds`
--

CREATE TABLE Volume_Discount_Thresholds (
  i_vd_threshold int(10) unsigned NOT NULL auto_increment,
  i_vd_dg int(10) unsigned NOT NULL default '0',
  threshold decimal(15,5) default NULL,
  discount decimal(15,5) NOT NULL default '0.00000',
  PRIMARY KEY  (i_vd_threshold)
) TYPE=InnoDB;

--
-- Table structure for table `X_Rate_Source`
--

CREATE TABLE X_Rate_Source (
  i_x_rate_source smallint(5) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  PRIMARY KEY  (i_x_rate_source)
) TYPE=InnoDB;

--
-- Table structure for table `X_Rates`
--

CREATE TABLE X_Rates (
  i_x_rate int(10) unsigned NOT NULL auto_increment,
  i_x_rate_source smallint(5) unsigned NOT NULL default '0',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  iso_4217 char(3) NOT NULL default '',
  base_iso_4217 char(3) NOT NULL default '',
  base_units decimal(15,5) unsigned NOT NULL default '0.00000',
  i_env tinyint(1) unsigned default '0',
  PRIMARY KEY  (i_x_rate),
  KEY xrates (iso_4217,base_iso_4217,timestamp,i_x_rate_source,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Accounts`
--

CREATE TABLE fake_Accounts (
  i_account int(10) unsigned NOT NULL auto_increment,
  id char(32) NOT NULL default '',
  password char(16) default NULL,
  h323_password char(255) default NULL,
  balance decimal(15,5) default NULL,
  opening_balance decimal(15,5) default NULL,
  issue_date date NOT NULL default '0000-00-00',
  zero_balance_date date default NULL,
  i_customer int(10) unsigned NOT NULL default '0',
  billing_model tinyint(2) NOT NULL default '0',
  activation_date date NOT NULL default '0000-00-00',
  expiration_date date default NULL,
  i_product int(10) unsigned NOT NULL default '0',
  blocked char(1) NOT NULL default 'N',
  last_usage datetime default NULL,
  i_batch int(10) unsigned NOT NULL default '0',
  i_env tinyint(1) unsigned NOT NULL default '1',
  first_usage date default NULL,
  life_time smallint(4) unsigned default NULL,
  redirect_number char(15) default NULL,
  control_number int(10) unsigned NOT NULL default '0',
  iso_639_1 char(2) default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  credit_limit decimal(15,5) default NULL,
  iso_4217 char(3) NOT NULL default '',
  non_call_related_charges decimal(15,5) default NULL,
  refunds decimal(15,5) default NULL,
  login char(32) default NULL,
  email char(128) default NULL,
  password_timestamp datetime default NULL,
  um_enabled char(1) NOT NULL default 'N',
  i_acl int(10) unsigned NOT NULL default '155',
  i_subscriber int(10) unsigned default NULL,
  i_lang char(5) default NULL,
  ua_profile_id int(10) unsigned default NULL,
  mac char(23) default NULL,
  follow_me_enabled char(1) NOT NULL default 'N',
  timer datetime default NULL,
  ecommerce_enabled char(1) default 'N',
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  i_vd_plan int(10) unsigned default NULL,
  last_recharge datetime default NULL,
  i_moh int(10) unsigned default NULL,
  service_flags char(32) NOT NULL default '',
  PRIMARY KEY  (i_account),
  UNIQUE KEY Accounts_id (id,i_env),
  UNIQUE KEY Accounts_cn_batch (i_batch,control_number),
  UNIQUE KEY Accounts_login (login),
  KEY Account_customer (i_customer),
  KEY Accounts_product (i_product),
  KEY AccountsProfileId (ua_profile_id),
  KEY Accounts_mac (mac,i_env),
  KEY Accounts_um_enabled (um_enabled),
  KEY Accounts_iso_4217 (iso_4217),
  KEY env_id (i_env,id),
  KEY AccountFirstUsage (first_usage),
  KEY i_vd_plan (i_vd_plan)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Batch`
--

CREATE TABLE fake_Batch (
  i_batch int(10) unsigned NOT NULL auto_increment,
  name char(32) NOT NULL default '',
  iso_4217 char(3) NOT NULL default '',
  description char(255) default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_customer int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (i_batch),
  UNIQUE KEY batch (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `fake_CDR_Accounts`
--

CREATE TABLE fake_CDR_Accounts (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  voice_quality tinyint(2) unsigned default NULL,
  duration mediumint(8) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  acc_flag char(1) NOT NULL default 'V',
  account_id char(32) default NULL,
  i_dest int(10) unsigned NOT NULL default '0',
  charged_time mediumint(8) unsigned NOT NULL default '0',
  charged_amount decimal(15,5) default NULL,
  history char(32) default NULL,
  i_vendor int(10) unsigned default NULL,
  cost decimal(15,5) default NULL,
  i_customer int(10) unsigned NOT NULL default '0',
  call_id char(1) default NULL,
  i_account int(10) unsigned default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY i_account (i_account),
  KEY CLD (CLD),
  KEY connect_time (connect_time),
  KEY i_dest (i_dest),
  KEY account_id (i_env,account_id),
  KEY conf_id (h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `fake_CDR_Customers`
--

CREATE TABLE fake_CDR_Customers (
  id int(10) unsigned NOT NULL auto_increment,
  i_env tinyint(1) unsigned NOT NULL default '1',
  h323_conf_id char(36) default NULL,
  CLI char(32) NOT NULL default '',
  CLD char(32) NOT NULL default '',
  setup_time mediumint(8) unsigned NOT NULL default '0',
  connect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_time datetime NOT NULL default '0000-00-00 00:00:00',
  disconnect_cause tinyint(2) unsigned NOT NULL default '0',
  voice_quality tinyint(2) unsigned default NULL,
  duration mediumint(8) unsigned NOT NULL default '0',
  time_flag char(1) NOT NULL default 'V',
  acc_flag char(1) NOT NULL default 'V',
  i_customer int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  charged_time mediumint(8) unsigned NOT NULL default '0',
  charged_amount decimal(15,5) default NULL,
  history char(32) default NULL,
  i_vendor int(10) unsigned default NULL,
  cost decimal(15,5) default NULL,
  call_id char(1) default NULL,
  i_tariff int(10) unsigned default NULL,
  i_rate int(10) unsigned default NULL,
  PRIMARY KEY  (id),
  KEY i_customer (i_customer),
  KEY CLD (CLD),
  KEY connect_time (connect_time),
  KEY i_dest (i_dest),
  KEY conf_id (h323_conf_id)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Customer_Notepad`
--

CREATE TABLE fake_Customer_Notepad (
  i_customer int(10) unsigned NOT NULL default '0',
  notepad text,
  PRIMARY KEY  (i_customer)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Customers`
--

CREATE TABLE fake_Customers (
  i_customer int(10) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  name char(41) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  balance decimal(15,5) default NULL,
  iso_4217 char(3) NOT NULL default '',
  companyname char(41) NOT NULL default '',
  salutation char(15) NOT NULL default '',
  firstname char(25) NOT NULL default '',
  midinit char(5) NOT NULL default '',
  lastname char(25) NOT NULL default '',
  baddr1 char(41) NOT NULL default '',
  baddr2 char(41) NOT NULL default '',
  baddr3 char(41) NOT NULL default '',
  baddr4 char(41) NOT NULL default '',
  baddr5 char(41) NOT NULL default '',
  city char(31) NOT NULL default '',
  state char(21) NOT NULL default '',
  zip char(13) NOT NULL default '',
  country char(31) NOT NULL default '',
  note char(41) NOT NULL default '',
  cont1 char(41) NOT NULL default '',
  phone1 char(21) NOT NULL default '',
  faxnum char(21) NOT NULL default '',
  phone2 char(21) NOT NULL default '',
  cont2 char(41) NOT NULL default '',
  email char(99) default NULL,
  bcc char(99) default NULL,
  send_statistics char(1) NOT NULL default 'N',
  login char(16) default NULL,
  password char(16) default NULL,
  i_customer_type int(10) unsigned NOT NULL default '1',
  i_billing_period tinyint(2) unsigned NOT NULL default '4',
  i_tariff int(10) unsigned default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  credit_limit decimal(15,5) default NULL,
  i_credit_card int(10) unsigned default NULL,
  i_env tinyint(1) unsigned NOT NULL default '1',
  i_template int(10) unsigned default NULL,
  tax_id char(16) default NULL,
  i_payment_term int(10) unsigned NOT NULL default '0',
  blocked enum('Y','N') NOT NULL default 'N',
  ppm_enabled char(1) NOT NULL default 'N',
  i_rep int(10) unsigned NOT NULL default '0',
  drm_enabled char(1) NOT NULL default 'N',
  max_abbreviated_length tinyint(1) unsigned default NULL,
  password_timestamp datetime default NULL,
  out_date_format char(16) NOT NULL default '',
  out_time_format char(16) NOT NULL default '',
  out_date_time_format char(32) NOT NULL default '',
  in_date_format char(16) NOT NULL default '',
  in_time_format char(16) NOT NULL default '',
  i_online_payment_processor tinyint(3) unsigned NOT NULL default '0',
  merch_acc_password char(64) default NULL,
  merch_acc_login char(64) default NULL,
  reccuring_enabled char(1) NOT NULL default 'N',
  test_mode char(1) NOT NULL default 'Y',
  i_acl int(10) unsigned NOT NULL default '0',
  opening_balance decimal(15,5) NOT NULL default '0.00000',
  min_allowed_payment decimal(15,5) unsigned NOT NULL default '0.00000',
  merch_acc_iso_4217 char(3) default NULL,
  cld_translation_rule char(255) default NULL,
  i_lang char(5) default NULL,
  i_tariff_incoming int(10) unsigned default NULL,
  credit_limit_warning char(25) default NULL,
  callshop_enabled char(1) NOT NULL default 'N',
  billed_to datetime default NULL,
  i_parent int(10) unsigned default NULL,
  i_routing_plan int(10) unsigned default NULL,
  i_vd_plan int(10) unsigned default NULL,
  creation_date datetime default NULL,
  cli_in_translation_rule char(255) default NULL,
  i_moh int(10) unsigned default NULL,
  service_flags char(32) NOT NULL default '',
  i_customer_class int(10) unsigned NOT NULL default '0',
  bp_charge_cc enum('N','Y') default NULL,
  unallocated_payments decimal(15,5) NOT NULL default '0.00000',
  bill_status enum('O','S','C') NOT NULL default 'O',
  PRIMARY KEY  (i_customer),
  UNIQUE KEY customer (name,i_env),
  UNIQUE KEY login (login),
  KEY parent_type (i_parent,i_customer_type),
  KEY i_tariff (i_tariff),
  KEY i_tariff_incoming (i_tariff_incoming),
  KEY Customers_iso_4217 (iso_4217),
  KEY i_vd_plan (i_vd_plan),
  KEY i_rep (i_rep),
  KEY i_template (i_template),
  KEY i_customer_class (i_customer_class),
  KEY bill_status (bill_status)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Destinations`
--

CREATE TABLE fake_Destinations (
  i_dest int(10) unsigned NOT NULL auto_increment,
  destination char(16) NOT NULL default '',
  iso_3166_1_a2 char(2) default '',
  i_country_subdivision smallint(5) unsigned default NULL,
  i_time_zone int(10) unsigned default NULL,
  description char(64) NOT NULL default '',
  i_group int(10) unsigned default '0',
  i_env tinyint(1) unsigned default '1',
  dest_type char(20) default NULL,
  PRIMARY KEY  (i_dest),
  UNIQUE KEY destination (destination,i_env),
  KEY iso_3166_1_a2 (iso_3166_1_a2),
  KEY Destinations_i_group (i_group),
  KEY env_dest_i_dest_iso (i_env,destination,i_dest,iso_3166_1_a2),
  KEY dest_type (dest_type)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Env`
--

CREATE TABLE fake_Env (
  i_env tinyint(1) unsigned NOT NULL auto_increment,
  name char(32) default NULL,
  description char(255) default NULL,
  companyname char(59) default NULL,
  addr1 char(41) default NULL,
  addr2 char(41) default NULL,
  addr3 char(41) default NULL,
  addr4 char(41) default NULL,
  iso_3166_1_a2 char(2) default NULL,
  phone char(51) default NULL,
  faxnum char(51) default NULL,
  email char(99) default NULL,
  web char(128) default NULL,
  lname char(59) default NULL,
  laddr1 char(41) default NULL,
  laddr2 char(41) default NULL,
  lcity char(31) default NULL,
  i_country_subdivision smallint(5) unsigned default NULL,
  lzip char(13) default NULL,
  liso_3166_1_a2 char(2) default NULL,
  tax_id char(16) default NULL,
  iso_4217 char(3) default NULL,
  i_billing_period tinyint(2) unsigned NOT NULL default '4',
  i_time_zone int(10) unsigned NOT NULL default '0',
  calls_counted_time datetime default NULL,
  billed_to datetime default NULL,
  PRIMARY KEY  (i_env)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Invoices`
--

CREATE TABLE fake_Invoices (
  i_invoice int(10) unsigned NOT NULL auto_increment,
  invoice_number int(10) unsigned NOT NULL default '0',
  i_customer int(10) unsigned NOT NULL default '0',
  issue_date date NOT NULL default '0000-00-00',
  period_from datetime NOT NULL default '0000-00-00 00:00:00',
  period_to datetime NOT NULL default '0000-00-00 00:00:00',
  i_payment_term int(10) unsigned NOT NULL default '1',
  amount_net decimal(15,5) default '0.00000',
  amount_due decimal(15,5) NOT NULL default '0.00000',
  closed char(1) NOT NULL default 'N',
  i_env tinyint(1) unsigned NOT NULL default '1',
  previous_balance decimal(15,5) default '0.00000',
  payments decimal(15,5) default '0.00000',
  subscriptions decimal(15,5) default '0.00000',
  manual_charges decimal(15,5) default '0.00000',
  taxes decimal(15,5) default '0.00000',
  calls decimal(15,5) default '0.00000',
  new_style tinyint(1) NOT NULL default '0',
  due_date date NOT NULL default '0000-00-00',
  i_invoice_status int(10) unsigned NOT NULL default '0',
  amount_paid decimal(15,5) NOT NULL default '0.00000',
  last_notific_date date default NULL,
  last_resend_date date default NULL,
  last_recollect_date date default NULL,
  last_warning_date date default NULL,
  last_suspension_date date default NULL,
  last_closing_date date default NULL,
  PRIMARY KEY  (i_invoice)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Payment_Terms`
--

CREATE TABLE fake_Payment_Terms (
  i_payment_term int(10) unsigned NOT NULL auto_increment,
  refnum char(32) default NULL,
  name char(31) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  discc_per decimal(9,5) NOT NULL default '0.00000',
  std_due_days smallint(6) default NULL,
  std_disc_days smallint(6) default NULL,
  day_of_month_due smallint(6) default NULL,
  disc_day_of_month smallint(6) default NULL,
  date_min_days smallint(6) default NULL,
  terms_type smallint(6) default NULL,
  hidden char(1) NOT NULL default 'N',
  i_env tinyint(1) default '1',
  default_term enum('Y','N') NOT NULL default 'N',
  PRIMARY KEY  (i_payment_term),
  UNIQUE KEY term_name (name,i_env)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Rates`
--

CREATE TABLE fake_Rates (
  i_tariff int(10) unsigned NOT NULL default '0',
  i_dest int(10) unsigned NOT NULL default '0',
  i_rate int(10) unsigned NOT NULL auto_increment,
  interval_1 smallint(5) unsigned NOT NULL default '1',
  interval_n smallint(5) unsigned NOT NULL default '1',
  price_1 float(15,5) unsigned NOT NULL default '0.00000',
  price_n float(15,5) unsigned NOT NULL default '0.00000',
  op_interval_1 smallint(5) unsigned NOT NULL default '1',
  op_interval_n smallint(5) unsigned NOT NULL default '1',
  op_price_1 float(15,5) unsigned NOT NULL default '0.00000',
  op_price_n float(15,5) unsigned NOT NULL default '0.00000',
  effective_from datetime NOT NULL default '0000-00-00 00:00:00',
  hidden char(1) NOT NULL default 'N',
  discontinued char(1) NOT NULL default 'N',
  forbidden char(1) NOT NULL default 'N',
  preference tinyint(1) unsigned NOT NULL default '5',
  huntstop char(1) NOT NULL default 'N',
  lot_time int(10) default NULL,
  formula varchar(255) default NULL,
  fake_rate char(1) NOT NULL default 'Y',
  i_master_rate int(10) unsigned default NULL,
  route_category tinyint(1) unsigned default NULL,
  op_route_category tinyint(1) unsigned default NULL,
  op_preference tinyint(1) unsigned default NULL,
  op_huntstop char(1) default 'N',
  PRIMARY KEY  (i_rate),
  KEY Rates_dest_index (i_dest),
  KEY Rates_i_tariff (i_tariff),
  KEY Rates_effective_from (effective_from),
  KEY master_rate (i_master_rate),
  KEY Rates_route_category (route_category,op_route_category),
  KEY tar_dest_effrom_rate (i_tariff,i_dest,effective_from,i_rate)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Representatives`
--

CREATE TABLE fake_Representatives (
  i_rep int(10) unsigned NOT NULL auto_increment,
  refnum varchar(32) default NULL,
  initials varchar(5) NOT NULL default '',
  name varchar(41) NOT NULL default '',
  timestamp datetime NOT NULL default '0000-00-00 00:00:00',
  iso_4217 char(3) NOT NULL default '',
  companyname varchar(41) NOT NULL default '',
  salutation varchar(15) NOT NULL default '',
  firstname varchar(25) NOT NULL default '',
  midinit varchar(5) NOT NULL default '',
  lastname varchar(25) NOT NULL default '',
  baddr1 varchar(41) NOT NULL default '',
  baddr2 varchar(41) NOT NULL default '',
  baddr3 varchar(41) NOT NULL default '',
  baddr4 varchar(41) NOT NULL default '',
  baddr5 varchar(41) NOT NULL default '',
  city varchar(31) NOT NULL default '',
  state varchar(21) NOT NULL default '',
  zip varchar(13) NOT NULL default '',
  country varchar(31) NOT NULL default '',
  cont1 varchar(41) NOT NULL default '',
  phone1 varchar(21) NOT NULL default '',
  faxnum varchar(21) NOT NULL default '',
  phone2 varchar(21) NOT NULL default '',
  cont2 varchar(41) NOT NULL default '',
  email varchar(99) default NULL,
  i_time_zone int(10) unsigned NOT NULL default '1',
  i_env tinyint(1) unsigned NOT NULL default '1',
  tax_id varchar(16) default NULL,
  hidden char(1) NOT NULL default 'N',
  i_customer int(10) unsigned default NULL,
  login varchar(16) default NULL,
  password varchar(16) default NULL,
  password_timestamp datetime default NULL,
  i_lang varchar(5) default NULL,
  i_acl int(10) unsigned NOT NULL default '0',
  out_date_format varchar(16) NOT NULL default '',
  out_time_format varchar(16) NOT NULL default '',
  out_date_time_format varchar(32) NOT NULL default '',
  in_date_format varchar(16) NOT NULL default '',
  in_time_format varchar(16) NOT NULL default '',
  PRIMARY KEY  (i_rep),
  UNIQUE KEY login (login),
  KEY env_name (i_env,name),
  KEY i_customer (i_customer)
) TYPE=InnoDB;

--
-- Table structure for table `fake_Tariffs`
--

CREATE TABLE fake_Tariffs (
  i_tariff int(10) unsigned NOT NULL auto_increment,
  name varchar(32) NOT NULL default '',
  period varchar(255) default NULL,
  currency char(3) NOT NULL default '',
  free_sec smallint(5) unsigned default '0',
  connect_fee decimal(15,5) unsigned NOT NULL default '0.00000',
  login_fee decimal(15,5) unsigned NOT NULL default '0.00000',
  i_env int(1) unsigned NOT NULL default '1',
  description varchar(255) NOT NULL default '',
  post_call_surcharge decimal(9,5) unsigned NOT NULL default '0.00000',
  i_tariff_template_upload int(10) unsigned default NULL,
  i_tariff_template_download int(10) unsigned default NULL,
  i_customer int(10) default NULL,
  short_description varchar(32) NOT NULL default '',
  routing_ext char(1) NOT NULL default 'N',
  volume_based char(1) default 'N',
  i_dest_group_set int(10) unsigned default NULL,
  rounding smallint(5) default NULL,
  formula varchar(255) default NULL,
  rating_mode enum('Standard','Fixed') default 'Standard',
  PRIMARY KEY  (i_tariff),
  UNIQUE KEY tariff (name,i_env),
  KEY i_tariff_template_upload (i_tariff_template_upload),
  KEY i_tariff_template_download (i_tariff_template_download)
) TYPE=InnoDB;

--
-- Table structure for table `mrkoin_invoice_a`
--

CREATE TABLE mrkoin_invoice_a (
  i_invoice int(11) unsigned default NULL,
  i_customer int(11) unsigned default NULL,
  due_date datetime default NULL,
  period_from datetime default NULL,
  previous_balance decimal(15,7) default NULL,
  KEY i_invoice (i_invoice)
) TYPE=InnoDB;

