# pbs001.pp

# module porta-billing slave
# v 001
#
# Created on 111108 by andre.guimaraes@switzernet.com
#

import "mysql-server.pp"
import "postfix.pp"
import "perl.pp"

class pbs001{

	$module_name = "pbs001"
	include mysql-server
	include postfix	
        include perl

	package{[libdbi-perl, libdbd-mysql-perl, ntp, ngrep]:
		ensure      => installed,
                require     => Package["mysql-server"],
	}

        define packagesCPAN {
                perl::installCPAN {    ["YAML",
                                        "Config::IniFiles",
                                        "List::Util",
                                        "Sys::Syslog",
                                        "MIME::Lite",
                                        "Date::Manip"]:
                }
        }

        packagesCPAN{"mysql":
                require     => Package["mysql-server"]
        }


        file { "/etc/pbs":
                ensure      => directory,
        }

        file{"/etc/pbs/setup-mysql-replication.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/setup-mysql-replication.pl",
                require     => File["/etc/pbs"]
        }

        file{"/etc/cron.d/pbs":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/cronpbs",
        }

        file{"/etc/pbs/porta-billing.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/porta-billing.sql",
        }

        file{"/etc/pbs/porta-sip.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/porta-sip.sql",
        }

        file{"/etc/pbs/users.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/users.sql.erb"),
                require     => File["/etc/pbs"]
        }

        file{"/etc/pbs/setup-mysql-replication.conf":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/setup-mysql-replication.conf.erb"),
                require     => File["/etc/pbs"]
        }
        
        file{"/etc/pbs/Lister.pm":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/Lister.pm",
                require     => File["/etc/pbs"]
        }

         exec { "setup mysql replication":
                command     => "/etc/pbs/setup-mysql-replication.pl > /dev/null 2>&1",
                subscribe   => [Package["mysql-server"], File["/etc/pbs/setup-mysql-replication.conf"]],
                refreshonly => true,
                require     => [ File["/etc/pbs/setup-mysql-replication.conf"], File["/etc/pbs/porta-billing.sql"], File["/etc/pbs/porta-sip.sql"], PackagesCPAN["mysql"] , File["/etc/pbs/setup-mysql-replication.pl"] ]
        }
}

